#include "dxil_nir.h"

#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 120
 * transforms:
 *    ('u2u16', ('u2u8', 'a@16')) => ('iand', 'a', 255)
 *    ('u2u16', ('u2u8', 'a@32')) => ('u2u16', ('iand', 'a', 255))
 *    ('u2u16', ('u2u8', 'a@64')) => ('u2u16', ('iand', 'a', 255))
 *    ('u2u16', ('i2i8', 'a@16')) => ('u2u16', ('iand', 'a', 255))
 *    ('u2u16', ('i2i8', 'a@32')) => ('u2u16', ('iand', 'a', 255))
 *    ('u2u16', ('i2i8', 'a@64')) => ('u2u16', ('iand', 'a', 255))
 *    ('u2u16', ('f2u8', 'a')) => ('iand', ('f2u16', 'a'), 255)
 *    ('u2u16', ('f2i8', 'a')) => ('iand', ('f2i16', 'a'), 255)
 *    ('u2u32', ('u2u8', 'a@16')) => ('u2u32', ('iand', 'a', 255))
 *    ('u2u32', ('u2u8', 'a@32')) => ('iand', 'a', 255)
 *    ('u2u32', ('u2u8', 'a@64')) => ('u2u32', ('iand', 'a', 255))
 *    ('u2u32', ('i2i8', 'a@16')) => ('u2u32', ('iand', 'a', 255))
 *    ('u2u32', ('i2i8', 'a@32')) => ('u2u32', ('iand', 'a', 255))
 *    ('u2u32', ('i2i8', 'a@64')) => ('u2u32', ('iand', 'a', 255))
 *    ('u2u32', ('f2u8', 'a')) => ('iand', ('f2u32', 'a'), 255)
 *    ('u2u32', ('f2i8', 'a')) => ('iand', ('f2i32', 'a'), 255)
 *    ('u2u64', ('u2u8', 'a@16')) => ('u2u64', ('iand', 'a', 255))
 *    ('u2u64', ('u2u8', 'a@32')) => ('u2u64', ('iand', 'a', 255))
 *    ('u2u64', ('u2u8', 'a@64')) => ('iand', 'a', 255)
 *    ('u2u64', ('i2i8', 'a@16')) => ('u2u64', ('iand', 'a', 255))
 *    ('u2u64', ('i2i8', 'a@32')) => ('u2u64', ('iand', 'a', 255))
 *    ('u2u64', ('i2i8', 'a@64')) => ('u2u64', ('iand', 'a', 255))
 *    ('u2u64', ('f2u8', 'a')) => ('iand', ('f2u64', 'a'), 255)
 *    ('u2u64', ('f2i8', 'a')) => ('iand', ('f2i64', 'a'), 255)
 *    ('i2i16', ('u2u8', 'a@16')) => ('i2i16', ('ishr', ('ishl', 'a', 8), 8))
 *    ('i2i16', ('u2u8', 'a@32')) => ('i2i16', ('ishr', ('ishl', 'a', 24), 24))
 *    ('i2i16', ('u2u8', 'a@64')) => ('i2i16', ('ishr', ('ishl', 'a', 56), 56))
 *    ('i2i16', ('i2i8', 'a@16')) => ('ishr', ('ishl', 'a', 8), 8)
 *    ('i2i16', ('i2i8', 'a@32')) => ('i2i16', ('ishr', ('ishl', 'a', 24), 24))
 *    ('i2i16', ('i2i8', 'a@64')) => ('i2i16', ('ishr', ('ishl', 'a', 56), 56))
 *    ('i2i16', ('f2u8', 'a')) => ('ishr', ('ishl', ('f2u16', 'a'), 8), 8)
 *    ('i2i16', ('f2i8', 'a')) => ('ishr', ('ishl', ('f2i16', 'a'), 8), 8)
 *    ('i2i32', ('u2u8', 'a@16')) => ('i2i32', ('ishr', ('ishl', 'a', 8), 8))
 *    ('i2i32', ('u2u8', 'a@32')) => ('i2i32', ('ishr', ('ishl', 'a', 24), 24))
 *    ('i2i32', ('u2u8', 'a@64')) => ('i2i32', ('ishr', ('ishl', 'a', 56), 56))
 *    ('i2i32', ('i2i8', 'a@16')) => ('i2i32', ('ishr', ('ishl', 'a', 8), 8))
 *    ('i2i32', ('i2i8', 'a@32')) => ('ishr', ('ishl', 'a', 24), 24)
 *    ('i2i32', ('i2i8', 'a@64')) => ('i2i32', ('ishr', ('ishl', 'a', 56), 56))
 *    ('i2i32', ('f2u8', 'a')) => ('ishr', ('ishl', ('f2u32', 'a'), 24), 24)
 *    ('i2i32', ('f2i8', 'a')) => ('ishr', ('ishl', ('f2i32', 'a'), 24), 24)
 *    ('i2i64', ('u2u8', 'a@16')) => ('i2i64', ('ishr', ('ishl', 'a', 8), 8))
 *    ('i2i64', ('u2u8', 'a@32')) => ('i2i64', ('ishr', ('ishl', 'a', 24), 24))
 *    ('i2i64', ('u2u8', 'a@64')) => ('i2i64', ('ishr', ('ishl', 'a', 56), 56))
 *    ('i2i64', ('i2i8', 'a@16')) => ('i2i64', ('ishr', ('ishl', 'a', 8), 8))
 *    ('i2i64', ('i2i8', 'a@32')) => ('i2i64', ('ishr', ('ishl', 'a', 24), 24))
 *    ('i2i64', ('i2i8', 'a@64')) => ('ishr', ('ishl', 'a', 56), 56)
 *    ('i2i64', ('f2u8', 'a')) => ('ishr', ('ishl', ('f2u64', 'a'), 56), 56)
 *    ('i2i64', ('f2i8', 'a')) => ('ishr', ('ishl', ('f2i64', 'a'), 56), 56)
 *    ('u2f16', ('u2u8', 'a@16')) => ('u2f16', ('iand', 'a', 255))
 *    ('u2f16', ('u2u8', 'a@32')) => ('u2f16', ('iand', 'a', 255))
 *    ('u2f16', ('u2u8', 'a@64')) => ('u2f16', ('iand', 'a', 255))
 *    ('u2f16', ('i2i8', 'a@16')) => ('u2f16', ('iand', 'a', 255))
 *    ('u2f16', ('i2i8', 'a@32')) => ('u2f16', ('iand', 'a', 255))
 *    ('u2f16', ('i2i8', 'a@64')) => ('u2f16', ('iand', 'a', 255))
 *    ('u2f16', ('f2u8', 'a@16')) => ('fmin', ('fmax', 'a', 0.0), 255.0)
 *    ('u2f16', ('f2u8', 'a@32')) => ('f2f16', ('fmin', ('fmax', 'a', 0.0), 255.0))
 *    ('u2f16', ('f2u8', 'a@64')) => ('f2f16', ('fmin', ('fmax', 'a', 0.0), 255.0))
 *    ('u2f16', ('f2i8', 'a@16')) => ('fmin', ('fmax', 'a', 0.0), 255.0)
 *    ('u2f16', ('f2i8', 'a@32')) => ('f2f16', ('fmin', ('fmax', 'a', 0.0), 255.0))
 *    ('u2f16', ('f2i8', 'a@64')) => ('f2f16', ('fmin', ('fmax', 'a', 0.0), 255.0))
 *    ('u2f32', ('u2u8', 'a@16')) => ('u2f32', ('iand', 'a', 255))
 *    ('u2f32', ('u2u8', 'a@32')) => ('u2f32', ('iand', 'a', 255))
 *    ('u2f32', ('u2u8', 'a@64')) => ('u2f32', ('iand', 'a', 255))
 *    ('u2f32', ('i2i8', 'a@16')) => ('u2f32', ('iand', 'a', 255))
 *    ('u2f32', ('i2i8', 'a@32')) => ('u2f32', ('iand', 'a', 255))
 *    ('u2f32', ('i2i8', 'a@64')) => ('u2f32', ('iand', 'a', 255))
 *    ('u2f32', ('f2u8', 'a@16')) => ('f2f32', ('fmin', ('fmax', 'a', 0.0), 255.0))
 *    ('u2f32', ('f2u8', 'a@32')) => ('fmin', ('fmax', 'a', 0.0), 255.0)
 *    ('u2f32', ('f2u8', 'a@64')) => ('f2f32', ('fmin', ('fmax', 'a', 0.0), 255.0))
 *    ('u2f32', ('f2i8', 'a@16')) => ('f2f32', ('fmin', ('fmax', 'a', 0.0), 255.0))
 *    ('u2f32', ('f2i8', 'a@32')) => ('fmin', ('fmax', 'a', 0.0), 255.0)
 *    ('u2f32', ('f2i8', 'a@64')) => ('f2f32', ('fmin', ('fmax', 'a', 0.0), 255.0))
 *    ('u2f64', ('u2u8', 'a@16')) => ('u2f64', ('iand', 'a', 255))
 *    ('u2f64', ('u2u8', 'a@32')) => ('u2f64', ('iand', 'a', 255))
 *    ('u2f64', ('u2u8', 'a@64')) => ('u2f64', ('iand', 'a', 255))
 *    ('u2f64', ('i2i8', 'a@16')) => ('u2f64', ('iand', 'a', 255))
 *    ('u2f64', ('i2i8', 'a@32')) => ('u2f64', ('iand', 'a', 255))
 *    ('u2f64', ('i2i8', 'a@64')) => ('u2f64', ('iand', 'a', 255))
 *    ('u2f64', ('f2u8', 'a@16')) => ('f2f64', ('fmin', ('fmax', 'a', 0.0), 255.0))
 *    ('u2f64', ('f2u8', 'a@32')) => ('f2f64', ('fmin', ('fmax', 'a', 0.0), 255.0))
 *    ('u2f64', ('f2u8', 'a@64')) => ('fmin', ('fmax', 'a', 0.0), 255.0)
 *    ('u2f64', ('f2i8', 'a@16')) => ('f2f64', ('fmin', ('fmax', 'a', 0.0), 255.0))
 *    ('u2f64', ('f2i8', 'a@32')) => ('f2f64', ('fmin', ('fmax', 'a', 0.0), 255.0))
 *    ('u2f64', ('f2i8', 'a@64')) => ('fmin', ('fmax', 'a', 0.0), 255.0)
 *    ('i2f16', ('u2u8', 'a@16')) => ('i2f16', ('ishr', ('ishl', 'a', 8), 8))
 *    ('i2f16', ('u2u8', 'a@32')) => ('i2f16', ('ishr', ('ishl', 'a', 24), 24))
 *    ('i2f16', ('u2u8', 'a@64')) => ('i2f16', ('ishr', ('ishl', 'a', 56), 56))
 *    ('i2f16', ('i2i8', 'a@16')) => ('i2f16', ('ishr', ('ishl', 'a', 8), 8))
 *    ('i2f16', ('i2i8', 'a@32')) => ('i2f16', ('ishr', ('ishl', 'a', 24), 24))
 *    ('i2f16', ('i2i8', 'a@64')) => ('i2f16', ('ishr', ('ishl', 'a', 56), 56))
 *    ('i2f16', ('f2u8', 'a@16')) => ('fmin', ('fmax', 'a', -128.0), 127.0)
 *    ('i2f16', ('f2u8', 'a@32')) => ('f2f16', ('fmin', ('fmax', 'a', -128.0), 127.0))
 *    ('i2f16', ('f2u8', 'a@64')) => ('f2f16', ('fmin', ('fmax', 'a', -128.0), 127.0))
 *    ('i2f16', ('f2i8', 'a@16')) => ('fmin', ('fmax', 'a', -128.0), 127.0)
 *    ('i2f16', ('f2i8', 'a@32')) => ('f2f16', ('fmin', ('fmax', 'a', -128.0), 127.0))
 *    ('i2f16', ('f2i8', 'a@64')) => ('f2f16', ('fmin', ('fmax', 'a', -128.0), 127.0))
 *    ('i2f32', ('u2u8', 'a@16')) => ('i2f32', ('ishr', ('ishl', 'a', 8), 8))
 *    ('i2f32', ('u2u8', 'a@32')) => ('i2f32', ('ishr', ('ishl', 'a', 24), 24))
 *    ('i2f32', ('u2u8', 'a@64')) => ('i2f32', ('ishr', ('ishl', 'a', 56), 56))
 *    ('i2f32', ('i2i8', 'a@16')) => ('i2f32', ('ishr', ('ishl', 'a', 8), 8))
 *    ('i2f32', ('i2i8', 'a@32')) => ('i2f32', ('ishr', ('ishl', 'a', 24), 24))
 *    ('i2f32', ('i2i8', 'a@64')) => ('i2f32', ('ishr', ('ishl', 'a', 56), 56))
 *    ('i2f32', ('f2u8', 'a@16')) => ('f2f32', ('fmin', ('fmax', 'a', -128.0), 127.0))
 *    ('i2f32', ('f2u8', 'a@32')) => ('fmin', ('fmax', 'a', -128.0), 127.0)
 *    ('i2f32', ('f2u8', 'a@64')) => ('f2f32', ('fmin', ('fmax', 'a', -128.0), 127.0))
 *    ('i2f32', ('f2i8', 'a@16')) => ('f2f32', ('fmin', ('fmax', 'a', -128.0), 127.0))
 *    ('i2f32', ('f2i8', 'a@32')) => ('fmin', ('fmax', 'a', -128.0), 127.0)
 *    ('i2f32', ('f2i8', 'a@64')) => ('f2f32', ('fmin', ('fmax', 'a', -128.0), 127.0))
 *    ('i2f64', ('u2u8', 'a@16')) => ('i2f64', ('ishr', ('ishl', 'a', 8), 8))
 *    ('i2f64', ('u2u8', 'a@32')) => ('i2f64', ('ishr', ('ishl', 'a', 24), 24))
 *    ('i2f64', ('u2u8', 'a@64')) => ('i2f64', ('ishr', ('ishl', 'a', 56), 56))
 *    ('i2f64', ('i2i8', 'a@16')) => ('i2f64', ('ishr', ('ishl', 'a', 8), 8))
 *    ('i2f64', ('i2i8', 'a@32')) => ('i2f64', ('ishr', ('ishl', 'a', 24), 24))
 *    ('i2f64', ('i2i8', 'a@64')) => ('i2f64', ('ishr', ('ishl', 'a', 56), 56))
 *    ('i2f64', ('f2u8', 'a@16')) => ('f2f64', ('fmin', ('fmax', 'a', -128.0), 127.0))
 *    ('i2f64', ('f2u8', 'a@32')) => ('f2f64', ('fmin', ('fmax', 'a', -128.0), 127.0))
 *    ('i2f64', ('f2u8', 'a@64')) => ('fmin', ('fmax', 'a', -128.0), 127.0)
 *    ('i2f64', ('f2i8', 'a@16')) => ('f2f64', ('fmin', ('fmax', 'a', -128.0), 127.0))
 *    ('i2f64', ('f2i8', 'a@32')) => ('f2f64', ('fmin', ('fmax', 'a', -128.0), 127.0))
 *    ('i2f64', ('f2i8', 'a@64')) => ('fmin', ('fmax', 'a', -128.0), 127.0)
 */


   static const nir_search_variable search0_0_0 = {
   { nir_search_value_variable, 16 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
};
static const nir_search_expression search0_0 = {
   { nir_search_value_expression, 8 },
   false, false,
   -1, 0,
   nir_op_u2u8,
   { &search0_0_0.value },
   NULL,
};
static const nir_search_expression search0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2u16,
   { &search0_0.value },
   NULL,
};

   /* replace0_0 -> search0_0_0 in the cache */

static const nir_search_constant replace0_1 = {
   { nir_search_value_constant, 16 },
   nir_type_int, { 0xff /* 255 */ },
};
static const nir_search_expression replace0 = {
   { nir_search_value_expression, 16 },
   false, false,
   0, 1,
   nir_op_iand,
   { &search0_0_0.value, &replace0_1.value },
   NULL,
};

   static const nir_search_variable search1_0_0 = {
   { nir_search_value_variable, 32 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
};
static const nir_search_expression search1_0 = {
   { nir_search_value_expression, 8 },
   false, false,
   -1, 0,
   nir_op_u2u8,
   { &search1_0_0.value },
   NULL,
};
static const nir_search_expression search1 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2u16,
   { &search1_0.value },
   NULL,
};

   /* replace1_0_0 -> search1_0_0 in the cache */

static const nir_search_constant replace1_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xff /* 255 */ },
};
static const nir_search_expression replace1_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   0, 1,
   nir_op_iand,
   { &search1_0_0.value, &replace1_0_1.value },
   NULL,
};
static const nir_search_expression replace1 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 1,
   nir_op_u2u16,
   { &replace1_0.value },
   NULL,
};

   static const nir_search_variable search2_0_0 = {
   { nir_search_value_variable, 64 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
};
static const nir_search_expression search2_0 = {
   { nir_search_value_expression, 8 },
   false, false,
   -1, 0,
   nir_op_u2u8,
   { &search2_0_0.value },
   NULL,
};
static const nir_search_expression search2 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2u16,
   { &search2_0.value },
   NULL,
};

   /* replace2_0_0 -> search2_0_0 in the cache */

static const nir_search_constant replace2_0_1 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0xff /* 255 */ },
};
static const nir_search_expression replace2_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   0, 1,
   nir_op_iand,
   { &search2_0_0.value, &replace2_0_1.value },
   NULL,
};
static const nir_search_expression replace2 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 1,
   nir_op_u2u16,
   { &replace2_0.value },
   NULL,
};

   /* search3_0_0 -> search0_0_0 in the cache */
static const nir_search_expression search3_0 = {
   { nir_search_value_expression, 8 },
   false, false,
   -1, 0,
   nir_op_i2i8,
   { &search0_0_0.value },
   NULL,
};
static const nir_search_expression search3 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2u16,
   { &search3_0.value },
   NULL,
};

   /* replace3_0_0 -> search0_0_0 in the cache */

/* replace3_0_1 -> replace0_1 in the cache */
/* replace3_0 -> replace0 in the cache */
static const nir_search_expression replace3 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 1,
   nir_op_u2u16,
   { &replace0.value },
   NULL,
};

   /* search4_0_0 -> search1_0_0 in the cache */
static const nir_search_expression search4_0 = {
   { nir_search_value_expression, 8 },
   false, false,
   -1, 0,
   nir_op_i2i8,
   { &search1_0_0.value },
   NULL,
};
static const nir_search_expression search4 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2u16,
   { &search4_0.value },
   NULL,
};

   /* replace4_0_0 -> search1_0_0 in the cache */

/* replace4_0_1 -> replace1_0_1 in the cache */
/* replace4_0 -> replace1_0 in the cache */
/* replace4 -> replace1 in the cache */

   /* search5_0_0 -> search2_0_0 in the cache */
static const nir_search_expression search5_0 = {
   { nir_search_value_expression, 8 },
   false, false,
   -1, 0,
   nir_op_i2i8,
   { &search2_0_0.value },
   NULL,
};
static const nir_search_expression search5 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2u16,
   { &search5_0.value },
   NULL,
};

   /* replace5_0_0 -> search2_0_0 in the cache */

/* replace5_0_1 -> replace2_0_1 in the cache */
/* replace5_0 -> replace2_0 in the cache */
/* replace5 -> replace2 in the cache */

   static const nir_search_variable search6_0_0 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
};
static const nir_search_expression search6_0 = {
   { nir_search_value_expression, 8 },
   false, false,
   -1, 0,
   nir_op_f2u8,
   { &search6_0_0.value },
   NULL,
};
static const nir_search_expression search6 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2u16,
   { &search6_0.value },
   NULL,
};

   /* replace6_0_0 -> search6_0_0 in the cache */
static const nir_search_expression replace6_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_f2u16,
   { &search6_0_0.value },
   NULL,
};

/* replace6_1 -> replace0_1 in the cache */
static const nir_search_expression replace6 = {
   { nir_search_value_expression, 16 },
   false, false,
   0, 1,
   nir_op_iand,
   { &replace6_0.value, &replace0_1.value },
   NULL,
};

   /* search7_0_0 -> search6_0_0 in the cache */
static const nir_search_expression search7_0 = {
   { nir_search_value_expression, 8 },
   false, false,
   -1, 0,
   nir_op_f2i8,
   { &search6_0_0.value },
   NULL,
};
static const nir_search_expression search7 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2u16,
   { &search7_0.value },
   NULL,
};

   /* replace7_0_0 -> search6_0_0 in the cache */
static const nir_search_expression replace7_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_f2i16,
   { &search6_0_0.value },
   NULL,
};

/* replace7_1 -> replace0_1 in the cache */
static const nir_search_expression replace7 = {
   { nir_search_value_expression, 16 },
   false, false,
   0, 1,
   nir_op_iand,
   { &replace7_0.value, &replace0_1.value },
   NULL,
};

   /* search8_0_0 -> search0_0_0 in the cache */
/* search8_0 -> search0_0 in the cache */
static const nir_search_expression search8 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2u32,
   { &search0_0.value },
   NULL,
};

   /* replace8_0_0 -> search0_0_0 in the cache */

/* replace8_0_1 -> replace0_1 in the cache */
/* replace8_0 -> replace0 in the cache */
static const nir_search_expression replace8 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 1,
   nir_op_u2u32,
   { &replace0.value },
   NULL,
};

   /* search9_0_0 -> search1_0_0 in the cache */
/* search9_0 -> search1_0 in the cache */
static const nir_search_expression search9 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2u32,
   { &search1_0.value },
   NULL,
};

   /* replace9_0 -> search1_0_0 in the cache */

/* replace9_1 -> replace1_0_1 in the cache */
/* replace9 -> replace1_0 in the cache */

   /* search10_0_0 -> search2_0_0 in the cache */
/* search10_0 -> search2_0 in the cache */
static const nir_search_expression search10 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2u32,
   { &search2_0.value },
   NULL,
};

   /* replace10_0_0 -> search2_0_0 in the cache */

/* replace10_0_1 -> replace2_0_1 in the cache */
/* replace10_0 -> replace2_0 in the cache */
static const nir_search_expression replace10 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 1,
   nir_op_u2u32,
   { &replace2_0.value },
   NULL,
};

   /* search11_0_0 -> search0_0_0 in the cache */
/* search11_0 -> search3_0 in the cache */
static const nir_search_expression search11 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2u32,
   { &search3_0.value },
   NULL,
};

   /* replace11_0_0 -> search0_0_0 in the cache */

/* replace11_0_1 -> replace0_1 in the cache */
/* replace11_0 -> replace0 in the cache */
/* replace11 -> replace8 in the cache */

   /* search12_0_0 -> search1_0_0 in the cache */
/* search12_0 -> search4_0 in the cache */
static const nir_search_expression search12 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2u32,
   { &search4_0.value },
   NULL,
};

   /* replace12_0_0 -> search1_0_0 in the cache */

/* replace12_0_1 -> replace1_0_1 in the cache */
/* replace12_0 -> replace1_0 in the cache */
static const nir_search_expression replace12 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 1,
   nir_op_u2u32,
   { &replace1_0.value },
   NULL,
};

   /* search13_0_0 -> search2_0_0 in the cache */
/* search13_0 -> search5_0 in the cache */
static const nir_search_expression search13 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2u32,
   { &search5_0.value },
   NULL,
};

   /* replace13_0_0 -> search2_0_0 in the cache */

/* replace13_0_1 -> replace2_0_1 in the cache */
/* replace13_0 -> replace2_0 in the cache */
/* replace13 -> replace10 in the cache */

   /* search14_0_0 -> search6_0_0 in the cache */
/* search14_0 -> search6_0 in the cache */
static const nir_search_expression search14 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2u32,
   { &search6_0.value },
   NULL,
};

   /* replace14_0_0 -> search6_0_0 in the cache */
static const nir_search_expression replace14_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_f2u32,
   { &search6_0_0.value },
   NULL,
};

/* replace14_1 -> replace1_0_1 in the cache */
static const nir_search_expression replace14 = {
   { nir_search_value_expression, 32 },
   false, false,
   0, 1,
   nir_op_iand,
   { &replace14_0.value, &replace1_0_1.value },
   NULL,
};

   /* search15_0_0 -> search6_0_0 in the cache */
/* search15_0 -> search7_0 in the cache */
static const nir_search_expression search15 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2u32,
   { &search7_0.value },
   NULL,
};

   /* replace15_0_0 -> search6_0_0 in the cache */
static const nir_search_expression replace15_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_f2i32,
   { &search6_0_0.value },
   NULL,
};

/* replace15_1 -> replace1_0_1 in the cache */
static const nir_search_expression replace15 = {
   { nir_search_value_expression, 32 },
   false, false,
   0, 1,
   nir_op_iand,
   { &replace15_0.value, &replace1_0_1.value },
   NULL,
};

   /* search16_0_0 -> search0_0_0 in the cache */
/* search16_0 -> search0_0 in the cache */
static const nir_search_expression search16 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2u64,
   { &search0_0.value },
   NULL,
};

   /* replace16_0_0 -> search0_0_0 in the cache */

/* replace16_0_1 -> replace0_1 in the cache */
/* replace16_0 -> replace0 in the cache */
static const nir_search_expression replace16 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 1,
   nir_op_u2u64,
   { &replace0.value },
   NULL,
};

   /* search17_0_0 -> search1_0_0 in the cache */
/* search17_0 -> search1_0 in the cache */
static const nir_search_expression search17 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2u64,
   { &search1_0.value },
   NULL,
};

   /* replace17_0_0 -> search1_0_0 in the cache */

/* replace17_0_1 -> replace1_0_1 in the cache */
/* replace17_0 -> replace1_0 in the cache */
static const nir_search_expression replace17 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 1,
   nir_op_u2u64,
   { &replace1_0.value },
   NULL,
};

   /* search18_0_0 -> search2_0_0 in the cache */
/* search18_0 -> search2_0 in the cache */
static const nir_search_expression search18 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2u64,
   { &search2_0.value },
   NULL,
};

   /* replace18_0 -> search2_0_0 in the cache */

/* replace18_1 -> replace2_0_1 in the cache */
/* replace18 -> replace2_0 in the cache */

   /* search19_0_0 -> search0_0_0 in the cache */
/* search19_0 -> search3_0 in the cache */
static const nir_search_expression search19 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2u64,
   { &search3_0.value },
   NULL,
};

   /* replace19_0_0 -> search0_0_0 in the cache */

/* replace19_0_1 -> replace0_1 in the cache */
/* replace19_0 -> replace0 in the cache */
/* replace19 -> replace16 in the cache */

   /* search20_0_0 -> search1_0_0 in the cache */
/* search20_0 -> search4_0 in the cache */
static const nir_search_expression search20 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2u64,
   { &search4_0.value },
   NULL,
};

   /* replace20_0_0 -> search1_0_0 in the cache */

/* replace20_0_1 -> replace1_0_1 in the cache */
/* replace20_0 -> replace1_0 in the cache */
/* replace20 -> replace17 in the cache */

   /* search21_0_0 -> search2_0_0 in the cache */
/* search21_0 -> search5_0 in the cache */
static const nir_search_expression search21 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2u64,
   { &search5_0.value },
   NULL,
};

   /* replace21_0_0 -> search2_0_0 in the cache */

/* replace21_0_1 -> replace2_0_1 in the cache */
/* replace21_0 -> replace2_0 in the cache */
static const nir_search_expression replace21 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 1,
   nir_op_u2u64,
   { &replace2_0.value },
   NULL,
};

   /* search22_0_0 -> search6_0_0 in the cache */
/* search22_0 -> search6_0 in the cache */
static const nir_search_expression search22 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2u64,
   { &search6_0.value },
   NULL,
};

   /* replace22_0_0 -> search6_0_0 in the cache */
static const nir_search_expression replace22_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_f2u64,
   { &search6_0_0.value },
   NULL,
};

/* replace22_1 -> replace2_0_1 in the cache */
static const nir_search_expression replace22 = {
   { nir_search_value_expression, 64 },
   false, false,
   0, 1,
   nir_op_iand,
   { &replace22_0.value, &replace2_0_1.value },
   NULL,
};

   /* search23_0_0 -> search6_0_0 in the cache */
/* search23_0 -> search7_0 in the cache */
static const nir_search_expression search23 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2u64,
   { &search7_0.value },
   NULL,
};

   /* replace23_0_0 -> search6_0_0 in the cache */
static const nir_search_expression replace23_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_f2i64,
   { &search6_0_0.value },
   NULL,
};

/* replace23_1 -> replace2_0_1 in the cache */
static const nir_search_expression replace23 = {
   { nir_search_value_expression, 64 },
   false, false,
   0, 1,
   nir_op_iand,
   { &replace23_0.value, &replace2_0_1.value },
   NULL,
};

   /* search24_0_0 -> search0_0_0 in the cache */
/* search24_0 -> search0_0 in the cache */
static const nir_search_expression search24 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2i16,
   { &search0_0.value },
   NULL,
};

   /* replace24_0_0_0 -> search0_0_0 in the cache */

static const nir_search_constant replace24_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x8 /* 8 */ },
};
static const nir_search_expression replace24_0_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_ishl,
   { &search0_0_0.value, &replace24_0_0_1.value },
   NULL,
};

/* replace24_0_1 -> replace24_0_0_1 in the cache */
static const nir_search_expression replace24_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_ishr,
   { &replace24_0_0.value, &replace24_0_0_1.value },
   NULL,
};
static const nir_search_expression replace24 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2i16,
   { &replace24_0.value },
   NULL,
};

   /* search25_0_0 -> search1_0_0 in the cache */
/* search25_0 -> search1_0 in the cache */
static const nir_search_expression search25 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2i16,
   { &search1_0.value },
   NULL,
};

   /* replace25_0_0_0 -> search1_0_0 in the cache */

static const nir_search_constant replace25_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x18 /* 24 */ },
};
static const nir_search_expression replace25_0_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_ishl,
   { &search1_0_0.value, &replace25_0_0_1.value },
   NULL,
};

/* replace25_0_1 -> replace25_0_0_1 in the cache */
static const nir_search_expression replace25_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_ishr,
   { &replace25_0_0.value, &replace25_0_0_1.value },
   NULL,
};
static const nir_search_expression replace25 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2i16,
   { &replace25_0.value },
   NULL,
};

   /* search26_0_0 -> search2_0_0 in the cache */
/* search26_0 -> search2_0 in the cache */
static const nir_search_expression search26 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2i16,
   { &search2_0.value },
   NULL,
};

   /* replace26_0_0_0 -> search2_0_0 in the cache */

static const nir_search_constant replace26_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x38 /* 56 */ },
};
static const nir_search_expression replace26_0_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_ishl,
   { &search2_0_0.value, &replace26_0_0_1.value },
   NULL,
};

/* replace26_0_1 -> replace26_0_0_1 in the cache */
static const nir_search_expression replace26_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_ishr,
   { &replace26_0_0.value, &replace26_0_0_1.value },
   NULL,
};
static const nir_search_expression replace26 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2i16,
   { &replace26_0.value },
   NULL,
};

   /* search27_0_0 -> search0_0_0 in the cache */
/* search27_0 -> search3_0 in the cache */
static const nir_search_expression search27 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2i16,
   { &search3_0.value },
   NULL,
};

   /* replace27_0_0 -> search0_0_0 in the cache */

/* replace27_0_1 -> replace24_0_0_1 in the cache */
/* replace27_0 -> replace24_0_0 in the cache */

/* replace27_1 -> replace24_0_0_1 in the cache */
/* replace27 -> replace24_0 in the cache */

   /* search28_0_0 -> search1_0_0 in the cache */
/* search28_0 -> search4_0 in the cache */
static const nir_search_expression search28 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2i16,
   { &search4_0.value },
   NULL,
};

   /* replace28_0_0_0 -> search1_0_0 in the cache */

/* replace28_0_0_1 -> replace25_0_0_1 in the cache */
/* replace28_0_0 -> replace25_0_0 in the cache */

/* replace28_0_1 -> replace25_0_0_1 in the cache */
/* replace28_0 -> replace25_0 in the cache */
/* replace28 -> replace25 in the cache */

   /* search29_0_0 -> search2_0_0 in the cache */
/* search29_0 -> search5_0 in the cache */
static const nir_search_expression search29 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2i16,
   { &search5_0.value },
   NULL,
};

   /* replace29_0_0_0 -> search2_0_0 in the cache */

/* replace29_0_0_1 -> replace26_0_0_1 in the cache */
/* replace29_0_0 -> replace26_0_0 in the cache */

/* replace29_0_1 -> replace26_0_0_1 in the cache */
/* replace29_0 -> replace26_0 in the cache */
/* replace29 -> replace26 in the cache */

   /* search30_0_0 -> search6_0_0 in the cache */
/* search30_0 -> search6_0 in the cache */
static const nir_search_expression search30 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2i16,
   { &search6_0.value },
   NULL,
};

   /* replace30_0_0_0 -> search6_0_0 in the cache */
/* replace30_0_0 -> replace6_0 in the cache */

/* replace30_0_1 -> replace24_0_0_1 in the cache */
static const nir_search_expression replace30_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_ishl,
   { &replace6_0.value, &replace24_0_0_1.value },
   NULL,
};

/* replace30_1 -> replace24_0_0_1 in the cache */
static const nir_search_expression replace30 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_ishr,
   { &replace30_0.value, &replace24_0_0_1.value },
   NULL,
};

   /* search31_0_0 -> search6_0_0 in the cache */
/* search31_0 -> search7_0 in the cache */
static const nir_search_expression search31 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2i16,
   { &search7_0.value },
   NULL,
};

   /* replace31_0_0_0 -> search6_0_0 in the cache */
/* replace31_0_0 -> replace7_0 in the cache */

/* replace31_0_1 -> replace24_0_0_1 in the cache */
static const nir_search_expression replace31_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_ishl,
   { &replace7_0.value, &replace24_0_0_1.value },
   NULL,
};

/* replace31_1 -> replace24_0_0_1 in the cache */
static const nir_search_expression replace31 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_ishr,
   { &replace31_0.value, &replace24_0_0_1.value },
   NULL,
};

   /* search32_0_0 -> search0_0_0 in the cache */
/* search32_0 -> search0_0 in the cache */
static const nir_search_expression search32 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &search0_0.value },
   NULL,
};

   /* replace32_0_0_0 -> search0_0_0 in the cache */

/* replace32_0_0_1 -> replace24_0_0_1 in the cache */
/* replace32_0_0 -> replace24_0_0 in the cache */

/* replace32_0_1 -> replace24_0_0_1 in the cache */
/* replace32_0 -> replace24_0 in the cache */
static const nir_search_expression replace32 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &replace24_0.value },
   NULL,
};

   /* search33_0_0 -> search1_0_0 in the cache */
/* search33_0 -> search1_0 in the cache */
static const nir_search_expression search33 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &search1_0.value },
   NULL,
};

   /* replace33_0_0_0 -> search1_0_0 in the cache */

/* replace33_0_0_1 -> replace25_0_0_1 in the cache */
/* replace33_0_0 -> replace25_0_0 in the cache */

/* replace33_0_1 -> replace25_0_0_1 in the cache */
/* replace33_0 -> replace25_0 in the cache */
static const nir_search_expression replace33 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &replace25_0.value },
   NULL,
};

   /* search34_0_0 -> search2_0_0 in the cache */
/* search34_0 -> search2_0 in the cache */
static const nir_search_expression search34 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &search2_0.value },
   NULL,
};

   /* replace34_0_0_0 -> search2_0_0 in the cache */

/* replace34_0_0_1 -> replace26_0_0_1 in the cache */
/* replace34_0_0 -> replace26_0_0 in the cache */

/* replace34_0_1 -> replace26_0_0_1 in the cache */
/* replace34_0 -> replace26_0 in the cache */
static const nir_search_expression replace34 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &replace26_0.value },
   NULL,
};

   /* search35_0_0 -> search0_0_0 in the cache */
/* search35_0 -> search3_0 in the cache */
static const nir_search_expression search35 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &search3_0.value },
   NULL,
};

   /* replace35_0_0_0 -> search0_0_0 in the cache */

/* replace35_0_0_1 -> replace24_0_0_1 in the cache */
/* replace35_0_0 -> replace24_0_0 in the cache */

/* replace35_0_1 -> replace24_0_0_1 in the cache */
/* replace35_0 -> replace24_0 in the cache */
/* replace35 -> replace32 in the cache */

   /* search36_0_0 -> search1_0_0 in the cache */
/* search36_0 -> search4_0 in the cache */
static const nir_search_expression search36 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &search4_0.value },
   NULL,
};

   /* replace36_0_0 -> search1_0_0 in the cache */

/* replace36_0_1 -> replace25_0_0_1 in the cache */
/* replace36_0 -> replace25_0_0 in the cache */

/* replace36_1 -> replace25_0_0_1 in the cache */
/* replace36 -> replace25_0 in the cache */

   /* search37_0_0 -> search2_0_0 in the cache */
/* search37_0 -> search5_0 in the cache */
static const nir_search_expression search37 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &search5_0.value },
   NULL,
};

   /* replace37_0_0_0 -> search2_0_0 in the cache */

/* replace37_0_0_1 -> replace26_0_0_1 in the cache */
/* replace37_0_0 -> replace26_0_0 in the cache */

/* replace37_0_1 -> replace26_0_0_1 in the cache */
/* replace37_0 -> replace26_0 in the cache */
/* replace37 -> replace34 in the cache */

   /* search38_0_0 -> search6_0_0 in the cache */
/* search38_0 -> search6_0 in the cache */
static const nir_search_expression search38 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &search6_0.value },
   NULL,
};

   /* replace38_0_0_0 -> search6_0_0 in the cache */
/* replace38_0_0 -> replace14_0 in the cache */

/* replace38_0_1 -> replace25_0_0_1 in the cache */
static const nir_search_expression replace38_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_ishl,
   { &replace14_0.value, &replace25_0_0_1.value },
   NULL,
};

/* replace38_1 -> replace25_0_0_1 in the cache */
static const nir_search_expression replace38 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_ishr,
   { &replace38_0.value, &replace25_0_0_1.value },
   NULL,
};

   /* search39_0_0 -> search6_0_0 in the cache */
/* search39_0 -> search7_0 in the cache */
static const nir_search_expression search39 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &search7_0.value },
   NULL,
};

   /* replace39_0_0_0 -> search6_0_0 in the cache */
/* replace39_0_0 -> replace15_0 in the cache */

/* replace39_0_1 -> replace25_0_0_1 in the cache */
static const nir_search_expression replace39_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_ishl,
   { &replace15_0.value, &replace25_0_0_1.value },
   NULL,
};

/* replace39_1 -> replace25_0_0_1 in the cache */
static const nir_search_expression replace39 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_ishr,
   { &replace39_0.value, &replace25_0_0_1.value },
   NULL,
};

   /* search40_0_0 -> search0_0_0 in the cache */
/* search40_0 -> search0_0 in the cache */
static const nir_search_expression search40 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &search0_0.value },
   NULL,
};

   /* replace40_0_0_0 -> search0_0_0 in the cache */

/* replace40_0_0_1 -> replace24_0_0_1 in the cache */
/* replace40_0_0 -> replace24_0_0 in the cache */

/* replace40_0_1 -> replace24_0_0_1 in the cache */
/* replace40_0 -> replace24_0 in the cache */
static const nir_search_expression replace40 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &replace24_0.value },
   NULL,
};

   /* search41_0_0 -> search1_0_0 in the cache */
/* search41_0 -> search1_0 in the cache */
static const nir_search_expression search41 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &search1_0.value },
   NULL,
};

   /* replace41_0_0_0 -> search1_0_0 in the cache */

/* replace41_0_0_1 -> replace25_0_0_1 in the cache */
/* replace41_0_0 -> replace25_0_0 in the cache */

/* replace41_0_1 -> replace25_0_0_1 in the cache */
/* replace41_0 -> replace25_0 in the cache */
static const nir_search_expression replace41 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &replace25_0.value },
   NULL,
};

   /* search42_0_0 -> search2_0_0 in the cache */
/* search42_0 -> search2_0 in the cache */
static const nir_search_expression search42 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &search2_0.value },
   NULL,
};

   /* replace42_0_0_0 -> search2_0_0 in the cache */

/* replace42_0_0_1 -> replace26_0_0_1 in the cache */
/* replace42_0_0 -> replace26_0_0 in the cache */

/* replace42_0_1 -> replace26_0_0_1 in the cache */
/* replace42_0 -> replace26_0 in the cache */
static const nir_search_expression replace42 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &replace26_0.value },
   NULL,
};

   /* search43_0_0 -> search0_0_0 in the cache */
/* search43_0 -> search3_0 in the cache */
static const nir_search_expression search43 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &search3_0.value },
   NULL,
};

   /* replace43_0_0_0 -> search0_0_0 in the cache */

/* replace43_0_0_1 -> replace24_0_0_1 in the cache */
/* replace43_0_0 -> replace24_0_0 in the cache */

/* replace43_0_1 -> replace24_0_0_1 in the cache */
/* replace43_0 -> replace24_0 in the cache */
/* replace43 -> replace40 in the cache */

   /* search44_0_0 -> search1_0_0 in the cache */
/* search44_0 -> search4_0 in the cache */
static const nir_search_expression search44 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &search4_0.value },
   NULL,
};

   /* replace44_0_0_0 -> search1_0_0 in the cache */

/* replace44_0_0_1 -> replace25_0_0_1 in the cache */
/* replace44_0_0 -> replace25_0_0 in the cache */

/* replace44_0_1 -> replace25_0_0_1 in the cache */
/* replace44_0 -> replace25_0 in the cache */
/* replace44 -> replace41 in the cache */

   /* search45_0_0 -> search2_0_0 in the cache */
/* search45_0 -> search5_0 in the cache */
static const nir_search_expression search45 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &search5_0.value },
   NULL,
};

   /* replace45_0_0 -> search2_0_0 in the cache */

/* replace45_0_1 -> replace26_0_0_1 in the cache */
/* replace45_0 -> replace26_0_0 in the cache */

/* replace45_1 -> replace26_0_0_1 in the cache */
/* replace45 -> replace26_0 in the cache */

   /* search46_0_0 -> search6_0_0 in the cache */
/* search46_0 -> search6_0 in the cache */
static const nir_search_expression search46 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &search6_0.value },
   NULL,
};

   /* replace46_0_0_0 -> search6_0_0 in the cache */
/* replace46_0_0 -> replace22_0 in the cache */

/* replace46_0_1 -> replace26_0_0_1 in the cache */
static const nir_search_expression replace46_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_ishl,
   { &replace22_0.value, &replace26_0_0_1.value },
   NULL,
};

/* replace46_1 -> replace26_0_0_1 in the cache */
static const nir_search_expression replace46 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_ishr,
   { &replace46_0.value, &replace26_0_0_1.value },
   NULL,
};

   /* search47_0_0 -> search6_0_0 in the cache */
/* search47_0 -> search7_0 in the cache */
static const nir_search_expression search47 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &search7_0.value },
   NULL,
};

   /* replace47_0_0_0 -> search6_0_0 in the cache */
/* replace47_0_0 -> replace23_0 in the cache */

/* replace47_0_1 -> replace26_0_0_1 in the cache */
static const nir_search_expression replace47_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_ishl,
   { &replace23_0.value, &replace26_0_0_1.value },
   NULL,
};

/* replace47_1 -> replace26_0_0_1 in the cache */
static const nir_search_expression replace47 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_ishr,
   { &replace47_0.value, &replace26_0_0_1.value },
   NULL,
};

   /* search48_0_0 -> search0_0_0 in the cache */
/* search48_0 -> search0_0 in the cache */
static const nir_search_expression search48 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2f16,
   { &search0_0.value },
   NULL,
};

   /* replace48_0_0 -> search0_0_0 in the cache */

/* replace48_0_1 -> replace0_1 in the cache */
/* replace48_0 -> replace0 in the cache */
static const nir_search_expression replace48 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 1,
   nir_op_u2f16,
   { &replace0.value },
   NULL,
};

   /* search49_0_0 -> search1_0_0 in the cache */
/* search49_0 -> search1_0 in the cache */
static const nir_search_expression search49 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2f16,
   { &search1_0.value },
   NULL,
};

   /* replace49_0_0 -> search1_0_0 in the cache */

/* replace49_0_1 -> replace1_0_1 in the cache */
/* replace49_0 -> replace1_0 in the cache */
static const nir_search_expression replace49 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 1,
   nir_op_u2f16,
   { &replace1_0.value },
   NULL,
};

   /* search50_0_0 -> search2_0_0 in the cache */
/* search50_0 -> search2_0 in the cache */
static const nir_search_expression search50 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2f16,
   { &search2_0.value },
   NULL,
};

   /* replace50_0_0 -> search2_0_0 in the cache */

/* replace50_0_1 -> replace2_0_1 in the cache */
/* replace50_0 -> replace2_0 in the cache */
static const nir_search_expression replace50 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 1,
   nir_op_u2f16,
   { &replace2_0.value },
   NULL,
};

   /* search51_0_0 -> search0_0_0 in the cache */
/* search51_0 -> search3_0 in the cache */
static const nir_search_expression search51 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2f16,
   { &search3_0.value },
   NULL,
};

   /* replace51_0_0 -> search0_0_0 in the cache */

/* replace51_0_1 -> replace0_1 in the cache */
/* replace51_0 -> replace0 in the cache */
/* replace51 -> replace48 in the cache */

   /* search52_0_0 -> search1_0_0 in the cache */
/* search52_0 -> search4_0 in the cache */
static const nir_search_expression search52 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2f16,
   { &search4_0.value },
   NULL,
};

   /* replace52_0_0 -> search1_0_0 in the cache */

/* replace52_0_1 -> replace1_0_1 in the cache */
/* replace52_0 -> replace1_0 in the cache */
/* replace52 -> replace49 in the cache */

   /* search53_0_0 -> search2_0_0 in the cache */
/* search53_0 -> search5_0 in the cache */
static const nir_search_expression search53 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2f16,
   { &search5_0.value },
   NULL,
};

   /* replace53_0_0 -> search2_0_0 in the cache */

/* replace53_0_1 -> replace2_0_1 in the cache */
/* replace53_0 -> replace2_0 in the cache */
/* replace53 -> replace50 in the cache */

   /* search54_0_0 -> search0_0_0 in the cache */
static const nir_search_expression search54_0 = {
   { nir_search_value_expression, 8 },
   false, false,
   -1, 0,
   nir_op_f2u8,
   { &search0_0_0.value },
   NULL,
};
static const nir_search_expression search54 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2f16,
   { &search54_0.value },
   NULL,
};

   /* replace54_0_0 -> search0_0_0 in the cache */

static const nir_search_constant replace54_0_1 = {
   { nir_search_value_constant, 16 },
   nir_type_float, { 0x0 /* 0.0 */ },
};
static const nir_search_expression replace54_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   1, 1,
   nir_op_fmax,
   { &search0_0_0.value, &replace54_0_1.value },
   NULL,
};

static const nir_search_constant replace54_1 = {
   { nir_search_value_constant, 16 },
   nir_type_float, { 0x406fe00000000000 /* 255.0 */ },
};
static const nir_search_expression replace54 = {
   { nir_search_value_expression, 16 },
   false, false,
   0, 2,
   nir_op_fmin,
   { &replace54_0.value, &replace54_1.value },
   NULL,
};

   /* search55_0_0 -> search1_0_0 in the cache */
static const nir_search_expression search55_0 = {
   { nir_search_value_expression, 8 },
   false, false,
   -1, 0,
   nir_op_f2u8,
   { &search1_0_0.value },
   NULL,
};
static const nir_search_expression search55 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2f16,
   { &search55_0.value },
   NULL,
};

   /* replace55_0_0_0 -> search1_0_0 in the cache */

static const nir_search_constant replace55_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x0 /* 0.0 */ },
};
static const nir_search_expression replace55_0_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   1, 1,
   nir_op_fmax,
   { &search1_0_0.value, &replace55_0_0_1.value },
   NULL,
};

static const nir_search_constant replace55_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x406fe00000000000 /* 255.0 */ },
};
static const nir_search_expression replace55_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   0, 2,
   nir_op_fmin,
   { &replace55_0_0.value, &replace55_0_1.value },
   NULL,
};
static const nir_search_expression replace55 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 2,
   nir_op_f2f16,
   { &replace55_0.value },
   NULL,
};

   /* search56_0_0 -> search2_0_0 in the cache */
static const nir_search_expression search56_0 = {
   { nir_search_value_expression, 8 },
   false, false,
   -1, 0,
   nir_op_f2u8,
   { &search2_0_0.value },
   NULL,
};
static const nir_search_expression search56 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2f16,
   { &search56_0.value },
   NULL,
};

   /* replace56_0_0_0 -> search2_0_0 in the cache */

static const nir_search_constant replace56_0_0_1 = {
   { nir_search_value_constant, 64 },
   nir_type_float, { 0x0 /* 0.0 */ },
};
static const nir_search_expression replace56_0_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   1, 1,
   nir_op_fmax,
   { &search2_0_0.value, &replace56_0_0_1.value },
   NULL,
};

static const nir_search_constant replace56_0_1 = {
   { nir_search_value_constant, 64 },
   nir_type_float, { 0x406fe00000000000 /* 255.0 */ },
};
static const nir_search_expression replace56_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   0, 2,
   nir_op_fmin,
   { &replace56_0_0.value, &replace56_0_1.value },
   NULL,
};
static const nir_search_expression replace56 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 2,
   nir_op_f2f16,
   { &replace56_0.value },
   NULL,
};

   /* search57_0_0 -> search0_0_0 in the cache */
static const nir_search_expression search57_0 = {
   { nir_search_value_expression, 8 },
   false, false,
   -1, 0,
   nir_op_f2i8,
   { &search0_0_0.value },
   NULL,
};
static const nir_search_expression search57 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2f16,
   { &search57_0.value },
   NULL,
};

   /* replace57_0_0 -> search0_0_0 in the cache */

/* replace57_0_1 -> replace54_0_1 in the cache */
/* replace57_0 -> replace54_0 in the cache */

/* replace57_1 -> replace54_1 in the cache */
/* replace57 -> replace54 in the cache */

   /* search58_0_0 -> search1_0_0 in the cache */
static const nir_search_expression search58_0 = {
   { nir_search_value_expression, 8 },
   false, false,
   -1, 0,
   nir_op_f2i8,
   { &search1_0_0.value },
   NULL,
};
static const nir_search_expression search58 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2f16,
   { &search58_0.value },
   NULL,
};

   /* replace58_0_0_0 -> search1_0_0 in the cache */

/* replace58_0_0_1 -> replace55_0_0_1 in the cache */
/* replace58_0_0 -> replace55_0_0 in the cache */

/* replace58_0_1 -> replace55_0_1 in the cache */
/* replace58_0 -> replace55_0 in the cache */
/* replace58 -> replace55 in the cache */

   /* search59_0_0 -> search2_0_0 in the cache */
static const nir_search_expression search59_0 = {
   { nir_search_value_expression, 8 },
   false, false,
   -1, 0,
   nir_op_f2i8,
   { &search2_0_0.value },
   NULL,
};
static const nir_search_expression search59 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2f16,
   { &search59_0.value },
   NULL,
};

   /* replace59_0_0_0 -> search2_0_0 in the cache */

/* replace59_0_0_1 -> replace56_0_0_1 in the cache */
/* replace59_0_0 -> replace56_0_0 in the cache */

/* replace59_0_1 -> replace56_0_1 in the cache */
/* replace59_0 -> replace56_0 in the cache */
/* replace59 -> replace56 in the cache */

   /* search60_0_0 -> search0_0_0 in the cache */
/* search60_0 -> search0_0 in the cache */
static const nir_search_expression search60 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search0_0.value },
   NULL,
};

   /* replace60_0_0 -> search0_0_0 in the cache */

/* replace60_0_1 -> replace0_1 in the cache */
/* replace60_0 -> replace0 in the cache */
static const nir_search_expression replace60 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 1,
   nir_op_u2f32,
   { &replace0.value },
   NULL,
};

   /* search61_0_0 -> search1_0_0 in the cache */
/* search61_0 -> search1_0 in the cache */
static const nir_search_expression search61 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search1_0.value },
   NULL,
};

   /* replace61_0_0 -> search1_0_0 in the cache */

/* replace61_0_1 -> replace1_0_1 in the cache */
/* replace61_0 -> replace1_0 in the cache */
static const nir_search_expression replace61 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 1,
   nir_op_u2f32,
   { &replace1_0.value },
   NULL,
};

   /* search62_0_0 -> search2_0_0 in the cache */
/* search62_0 -> search2_0 in the cache */
static const nir_search_expression search62 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search2_0.value },
   NULL,
};

   /* replace62_0_0 -> search2_0_0 in the cache */

/* replace62_0_1 -> replace2_0_1 in the cache */
/* replace62_0 -> replace2_0 in the cache */
static const nir_search_expression replace62 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 1,
   nir_op_u2f32,
   { &replace2_0.value },
   NULL,
};

   /* search63_0_0 -> search0_0_0 in the cache */
/* search63_0 -> search3_0 in the cache */
static const nir_search_expression search63 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search3_0.value },
   NULL,
};

   /* replace63_0_0 -> search0_0_0 in the cache */

/* replace63_0_1 -> replace0_1 in the cache */
/* replace63_0 -> replace0 in the cache */
/* replace63 -> replace60 in the cache */

   /* search64_0_0 -> search1_0_0 in the cache */
/* search64_0 -> search4_0 in the cache */
static const nir_search_expression search64 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search4_0.value },
   NULL,
};

   /* replace64_0_0 -> search1_0_0 in the cache */

/* replace64_0_1 -> replace1_0_1 in the cache */
/* replace64_0 -> replace1_0 in the cache */
/* replace64 -> replace61 in the cache */

   /* search65_0_0 -> search2_0_0 in the cache */
/* search65_0 -> search5_0 in the cache */
static const nir_search_expression search65 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search5_0.value },
   NULL,
};

   /* replace65_0_0 -> search2_0_0 in the cache */

/* replace65_0_1 -> replace2_0_1 in the cache */
/* replace65_0 -> replace2_0 in the cache */
/* replace65 -> replace62 in the cache */

   /* search66_0_0 -> search0_0_0 in the cache */
/* search66_0 -> search54_0 in the cache */
static const nir_search_expression search66 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search54_0.value },
   NULL,
};

   /* replace66_0_0_0 -> search0_0_0 in the cache */

/* replace66_0_0_1 -> replace54_0_1 in the cache */
/* replace66_0_0 -> replace54_0 in the cache */

/* replace66_0_1 -> replace54_1 in the cache */
/* replace66_0 -> replace54 in the cache */
static const nir_search_expression replace66 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 2,
   nir_op_f2f32,
   { &replace54.value },
   NULL,
};

   /* search67_0_0 -> search1_0_0 in the cache */
/* search67_0 -> search55_0 in the cache */
static const nir_search_expression search67 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search55_0.value },
   NULL,
};

   /* replace67_0_0 -> search1_0_0 in the cache */

/* replace67_0_1 -> replace55_0_0_1 in the cache */
/* replace67_0 -> replace55_0_0 in the cache */

/* replace67_1 -> replace55_0_1 in the cache */
/* replace67 -> replace55_0 in the cache */

   /* search68_0_0 -> search2_0_0 in the cache */
/* search68_0 -> search56_0 in the cache */
static const nir_search_expression search68 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search56_0.value },
   NULL,
};

   /* replace68_0_0_0 -> search2_0_0 in the cache */

/* replace68_0_0_1 -> replace56_0_0_1 in the cache */
/* replace68_0_0 -> replace56_0_0 in the cache */

/* replace68_0_1 -> replace56_0_1 in the cache */
/* replace68_0 -> replace56_0 in the cache */
static const nir_search_expression replace68 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 2,
   nir_op_f2f32,
   { &replace56_0.value },
   NULL,
};

   /* search69_0_0 -> search0_0_0 in the cache */
/* search69_0 -> search57_0 in the cache */
static const nir_search_expression search69 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search57_0.value },
   NULL,
};

   /* replace69_0_0_0 -> search0_0_0 in the cache */

/* replace69_0_0_1 -> replace54_0_1 in the cache */
/* replace69_0_0 -> replace54_0 in the cache */

/* replace69_0_1 -> replace54_1 in the cache */
/* replace69_0 -> replace54 in the cache */
/* replace69 -> replace66 in the cache */

   /* search70_0_0 -> search1_0_0 in the cache */
/* search70_0 -> search58_0 in the cache */
static const nir_search_expression search70 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search58_0.value },
   NULL,
};

   /* replace70_0_0 -> search1_0_0 in the cache */

/* replace70_0_1 -> replace55_0_0_1 in the cache */
/* replace70_0 -> replace55_0_0 in the cache */

/* replace70_1 -> replace55_0_1 in the cache */
/* replace70 -> replace55_0 in the cache */

   /* search71_0_0 -> search2_0_0 in the cache */
/* search71_0 -> search59_0 in the cache */
static const nir_search_expression search71 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search59_0.value },
   NULL,
};

   /* replace71_0_0_0 -> search2_0_0 in the cache */

/* replace71_0_0_1 -> replace56_0_0_1 in the cache */
/* replace71_0_0 -> replace56_0_0 in the cache */

/* replace71_0_1 -> replace56_0_1 in the cache */
/* replace71_0 -> replace56_0 in the cache */
/* replace71 -> replace68 in the cache */

   /* search72_0_0 -> search0_0_0 in the cache */
/* search72_0 -> search0_0 in the cache */
static const nir_search_expression search72 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search0_0.value },
   NULL,
};

   /* replace72_0_0 -> search0_0_0 in the cache */

/* replace72_0_1 -> replace0_1 in the cache */
/* replace72_0 -> replace0 in the cache */
static const nir_search_expression replace72 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 1,
   nir_op_u2f64,
   { &replace0.value },
   NULL,
};

   /* search73_0_0 -> search1_0_0 in the cache */
/* search73_0 -> search1_0 in the cache */
static const nir_search_expression search73 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search1_0.value },
   NULL,
};

   /* replace73_0_0 -> search1_0_0 in the cache */

/* replace73_0_1 -> replace1_0_1 in the cache */
/* replace73_0 -> replace1_0 in the cache */
static const nir_search_expression replace73 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 1,
   nir_op_u2f64,
   { &replace1_0.value },
   NULL,
};

   /* search74_0_0 -> search2_0_0 in the cache */
/* search74_0 -> search2_0 in the cache */
static const nir_search_expression search74 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search2_0.value },
   NULL,
};

   /* replace74_0_0 -> search2_0_0 in the cache */

/* replace74_0_1 -> replace2_0_1 in the cache */
/* replace74_0 -> replace2_0 in the cache */
static const nir_search_expression replace74 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 1,
   nir_op_u2f64,
   { &replace2_0.value },
   NULL,
};

   /* search75_0_0 -> search0_0_0 in the cache */
/* search75_0 -> search3_0 in the cache */
static const nir_search_expression search75 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search3_0.value },
   NULL,
};

   /* replace75_0_0 -> search0_0_0 in the cache */

/* replace75_0_1 -> replace0_1 in the cache */
/* replace75_0 -> replace0 in the cache */
/* replace75 -> replace72 in the cache */

   /* search76_0_0 -> search1_0_0 in the cache */
/* search76_0 -> search4_0 in the cache */
static const nir_search_expression search76 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search4_0.value },
   NULL,
};

   /* replace76_0_0 -> search1_0_0 in the cache */

/* replace76_0_1 -> replace1_0_1 in the cache */
/* replace76_0 -> replace1_0 in the cache */
/* replace76 -> replace73 in the cache */

   /* search77_0_0 -> search2_0_0 in the cache */
/* search77_0 -> search5_0 in the cache */
static const nir_search_expression search77 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search5_0.value },
   NULL,
};

   /* replace77_0_0 -> search2_0_0 in the cache */

/* replace77_0_1 -> replace2_0_1 in the cache */
/* replace77_0 -> replace2_0 in the cache */
/* replace77 -> replace74 in the cache */

   /* search78_0_0 -> search0_0_0 in the cache */
/* search78_0 -> search54_0 in the cache */
static const nir_search_expression search78 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search54_0.value },
   NULL,
};

   /* replace78_0_0_0 -> search0_0_0 in the cache */

/* replace78_0_0_1 -> replace54_0_1 in the cache */
/* replace78_0_0 -> replace54_0 in the cache */

/* replace78_0_1 -> replace54_1 in the cache */
/* replace78_0 -> replace54 in the cache */
static const nir_search_expression replace78 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 2,
   nir_op_f2f64,
   { &replace54.value },
   NULL,
};

   /* search79_0_0 -> search1_0_0 in the cache */
/* search79_0 -> search55_0 in the cache */
static const nir_search_expression search79 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search55_0.value },
   NULL,
};

   /* replace79_0_0_0 -> search1_0_0 in the cache */

/* replace79_0_0_1 -> replace55_0_0_1 in the cache */
/* replace79_0_0 -> replace55_0_0 in the cache */

/* replace79_0_1 -> replace55_0_1 in the cache */
/* replace79_0 -> replace55_0 in the cache */
static const nir_search_expression replace79 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 2,
   nir_op_f2f64,
   { &replace55_0.value },
   NULL,
};

   /* search80_0_0 -> search2_0_0 in the cache */
/* search80_0 -> search56_0 in the cache */
static const nir_search_expression search80 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search56_0.value },
   NULL,
};

   /* replace80_0_0 -> search2_0_0 in the cache */

/* replace80_0_1 -> replace56_0_0_1 in the cache */
/* replace80_0 -> replace56_0_0 in the cache */

/* replace80_1 -> replace56_0_1 in the cache */
/* replace80 -> replace56_0 in the cache */

   /* search81_0_0 -> search0_0_0 in the cache */
/* search81_0 -> search57_0 in the cache */
static const nir_search_expression search81 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search57_0.value },
   NULL,
};

   /* replace81_0_0_0 -> search0_0_0 in the cache */

/* replace81_0_0_1 -> replace54_0_1 in the cache */
/* replace81_0_0 -> replace54_0 in the cache */

/* replace81_0_1 -> replace54_1 in the cache */
/* replace81_0 -> replace54 in the cache */
/* replace81 -> replace78 in the cache */

   /* search82_0_0 -> search1_0_0 in the cache */
/* search82_0 -> search58_0 in the cache */
static const nir_search_expression search82 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search58_0.value },
   NULL,
};

   /* replace82_0_0_0 -> search1_0_0 in the cache */

/* replace82_0_0_1 -> replace55_0_0_1 in the cache */
/* replace82_0_0 -> replace55_0_0 in the cache */

/* replace82_0_1 -> replace55_0_1 in the cache */
/* replace82_0 -> replace55_0 in the cache */
/* replace82 -> replace79 in the cache */

   /* search83_0_0 -> search2_0_0 in the cache */
/* search83_0 -> search59_0 in the cache */
static const nir_search_expression search83 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search59_0.value },
   NULL,
};

   /* replace83_0_0 -> search2_0_0 in the cache */

/* replace83_0_1 -> replace56_0_0_1 in the cache */
/* replace83_0 -> replace56_0_0 in the cache */

/* replace83_1 -> replace56_0_1 in the cache */
/* replace83 -> replace56_0 in the cache */

   /* search84_0_0 -> search0_0_0 in the cache */
/* search84_0 -> search0_0 in the cache */
static const nir_search_expression search84 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2f16,
   { &search0_0.value },
   NULL,
};

   /* replace84_0_0_0 -> search0_0_0 in the cache */

/* replace84_0_0_1 -> replace24_0_0_1 in the cache */
/* replace84_0_0 -> replace24_0_0 in the cache */

/* replace84_0_1 -> replace24_0_0_1 in the cache */
/* replace84_0 -> replace24_0 in the cache */
static const nir_search_expression replace84 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2f16,
   { &replace24_0.value },
   NULL,
};

   /* search85_0_0 -> search1_0_0 in the cache */
/* search85_0 -> search1_0 in the cache */
static const nir_search_expression search85 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2f16,
   { &search1_0.value },
   NULL,
};

   /* replace85_0_0_0 -> search1_0_0 in the cache */

/* replace85_0_0_1 -> replace25_0_0_1 in the cache */
/* replace85_0_0 -> replace25_0_0 in the cache */

/* replace85_0_1 -> replace25_0_0_1 in the cache */
/* replace85_0 -> replace25_0 in the cache */
static const nir_search_expression replace85 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2f16,
   { &replace25_0.value },
   NULL,
};

   /* search86_0_0 -> search2_0_0 in the cache */
/* search86_0 -> search2_0 in the cache */
static const nir_search_expression search86 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2f16,
   { &search2_0.value },
   NULL,
};

   /* replace86_0_0_0 -> search2_0_0 in the cache */

/* replace86_0_0_1 -> replace26_0_0_1 in the cache */
/* replace86_0_0 -> replace26_0_0 in the cache */

/* replace86_0_1 -> replace26_0_0_1 in the cache */
/* replace86_0 -> replace26_0 in the cache */
static const nir_search_expression replace86 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2f16,
   { &replace26_0.value },
   NULL,
};

   /* search87_0_0 -> search0_0_0 in the cache */
/* search87_0 -> search3_0 in the cache */
static const nir_search_expression search87 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2f16,
   { &search3_0.value },
   NULL,
};

   /* replace87_0_0_0 -> search0_0_0 in the cache */

/* replace87_0_0_1 -> replace24_0_0_1 in the cache */
/* replace87_0_0 -> replace24_0_0 in the cache */

/* replace87_0_1 -> replace24_0_0_1 in the cache */
/* replace87_0 -> replace24_0 in the cache */
/* replace87 -> replace84 in the cache */

   /* search88_0_0 -> search1_0_0 in the cache */
/* search88_0 -> search4_0 in the cache */
static const nir_search_expression search88 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2f16,
   { &search4_0.value },
   NULL,
};

   /* replace88_0_0_0 -> search1_0_0 in the cache */

/* replace88_0_0_1 -> replace25_0_0_1 in the cache */
/* replace88_0_0 -> replace25_0_0 in the cache */

/* replace88_0_1 -> replace25_0_0_1 in the cache */
/* replace88_0 -> replace25_0 in the cache */
/* replace88 -> replace85 in the cache */

   /* search89_0_0 -> search2_0_0 in the cache */
/* search89_0 -> search5_0 in the cache */
static const nir_search_expression search89 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2f16,
   { &search5_0.value },
   NULL,
};

   /* replace89_0_0_0 -> search2_0_0 in the cache */

/* replace89_0_0_1 -> replace26_0_0_1 in the cache */
/* replace89_0_0 -> replace26_0_0 in the cache */

/* replace89_0_1 -> replace26_0_0_1 in the cache */
/* replace89_0 -> replace26_0 in the cache */
/* replace89 -> replace86 in the cache */

   /* search90_0_0 -> search0_0_0 in the cache */
/* search90_0 -> search54_0 in the cache */
static const nir_search_expression search90 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2f16,
   { &search54_0.value },
   NULL,
};

   /* replace90_0_0 -> search0_0_0 in the cache */

static const nir_search_constant replace90_0_1 = {
   { nir_search_value_constant, 16 },
   nir_type_float, { 0xc060000000000000L /* -128.0 */ },
};
static const nir_search_expression replace90_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   1, 1,
   nir_op_fmax,
   { &search0_0_0.value, &replace90_0_1.value },
   NULL,
};

static const nir_search_constant replace90_1 = {
   { nir_search_value_constant, 16 },
   nir_type_float, { 0x405fc00000000000 /* 127.0 */ },
};
static const nir_search_expression replace90 = {
   { nir_search_value_expression, 16 },
   false, false,
   0, 2,
   nir_op_fmin,
   { &replace90_0.value, &replace90_1.value },
   NULL,
};

   /* search91_0_0 -> search1_0_0 in the cache */
/* search91_0 -> search55_0 in the cache */
static const nir_search_expression search91 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2f16,
   { &search55_0.value },
   NULL,
};

   /* replace91_0_0_0 -> search1_0_0 in the cache */

static const nir_search_constant replace91_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0xc060000000000000L /* -128.0 */ },
};
static const nir_search_expression replace91_0_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   1, 1,
   nir_op_fmax,
   { &search1_0_0.value, &replace91_0_0_1.value },
   NULL,
};

static const nir_search_constant replace91_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x405fc00000000000 /* 127.0 */ },
};
static const nir_search_expression replace91_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   0, 2,
   nir_op_fmin,
   { &replace91_0_0.value, &replace91_0_1.value },
   NULL,
};
static const nir_search_expression replace91 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 2,
   nir_op_f2f16,
   { &replace91_0.value },
   NULL,
};

   /* search92_0_0 -> search2_0_0 in the cache */
/* search92_0 -> search56_0 in the cache */
static const nir_search_expression search92 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2f16,
   { &search56_0.value },
   NULL,
};

   /* replace92_0_0_0 -> search2_0_0 in the cache */

static const nir_search_constant replace92_0_0_1 = {
   { nir_search_value_constant, 64 },
   nir_type_float, { 0xc060000000000000L /* -128.0 */ },
};
static const nir_search_expression replace92_0_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   1, 1,
   nir_op_fmax,
   { &search2_0_0.value, &replace92_0_0_1.value },
   NULL,
};

static const nir_search_constant replace92_0_1 = {
   { nir_search_value_constant, 64 },
   nir_type_float, { 0x405fc00000000000 /* 127.0 */ },
};
static const nir_search_expression replace92_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   0, 2,
   nir_op_fmin,
   { &replace92_0_0.value, &replace92_0_1.value },
   NULL,
};
static const nir_search_expression replace92 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 2,
   nir_op_f2f16,
   { &replace92_0.value },
   NULL,
};

   /* search93_0_0 -> search0_0_0 in the cache */
/* search93_0 -> search57_0 in the cache */
static const nir_search_expression search93 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2f16,
   { &search57_0.value },
   NULL,
};

   /* replace93_0_0 -> search0_0_0 in the cache */

/* replace93_0_1 -> replace90_0_1 in the cache */
/* replace93_0 -> replace90_0 in the cache */

/* replace93_1 -> replace90_1 in the cache */
/* replace93 -> replace90 in the cache */

   /* search94_0_0 -> search1_0_0 in the cache */
/* search94_0 -> search58_0 in the cache */
static const nir_search_expression search94 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2f16,
   { &search58_0.value },
   NULL,
};

   /* replace94_0_0_0 -> search1_0_0 in the cache */

/* replace94_0_0_1 -> replace91_0_0_1 in the cache */
/* replace94_0_0 -> replace91_0_0 in the cache */

/* replace94_0_1 -> replace91_0_1 in the cache */
/* replace94_0 -> replace91_0 in the cache */
/* replace94 -> replace91 in the cache */

   /* search95_0_0 -> search2_0_0 in the cache */
/* search95_0 -> search59_0 in the cache */
static const nir_search_expression search95 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2f16,
   { &search59_0.value },
   NULL,
};

   /* replace95_0_0_0 -> search2_0_0 in the cache */

/* replace95_0_0_1 -> replace92_0_0_1 in the cache */
/* replace95_0_0 -> replace92_0_0 in the cache */

/* replace95_0_1 -> replace92_0_1 in the cache */
/* replace95_0 -> replace92_0 in the cache */
/* replace95 -> replace92 in the cache */

   /* search96_0_0 -> search0_0_0 in the cache */
/* search96_0 -> search0_0 in the cache */
static const nir_search_expression search96 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search0_0.value },
   NULL,
};

   /* replace96_0_0_0 -> search0_0_0 in the cache */

/* replace96_0_0_1 -> replace24_0_0_1 in the cache */
/* replace96_0_0 -> replace24_0_0 in the cache */

/* replace96_0_1 -> replace24_0_0_1 in the cache */
/* replace96_0 -> replace24_0 in the cache */
static const nir_search_expression replace96 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &replace24_0.value },
   NULL,
};

   /* search97_0_0 -> search1_0_0 in the cache */
/* search97_0 -> search1_0 in the cache */
static const nir_search_expression search97 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search1_0.value },
   NULL,
};

   /* replace97_0_0_0 -> search1_0_0 in the cache */

/* replace97_0_0_1 -> replace25_0_0_1 in the cache */
/* replace97_0_0 -> replace25_0_0 in the cache */

/* replace97_0_1 -> replace25_0_0_1 in the cache */
/* replace97_0 -> replace25_0 in the cache */
static const nir_search_expression replace97 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &replace25_0.value },
   NULL,
};

   /* search98_0_0 -> search2_0_0 in the cache */
/* search98_0 -> search2_0 in the cache */
static const nir_search_expression search98 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search2_0.value },
   NULL,
};

   /* replace98_0_0_0 -> search2_0_0 in the cache */

/* replace98_0_0_1 -> replace26_0_0_1 in the cache */
/* replace98_0_0 -> replace26_0_0 in the cache */

/* replace98_0_1 -> replace26_0_0_1 in the cache */
/* replace98_0 -> replace26_0 in the cache */
static const nir_search_expression replace98 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &replace26_0.value },
   NULL,
};

   /* search99_0_0 -> search0_0_0 in the cache */
/* search99_0 -> search3_0 in the cache */
static const nir_search_expression search99 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search3_0.value },
   NULL,
};

   /* replace99_0_0_0 -> search0_0_0 in the cache */

/* replace99_0_0_1 -> replace24_0_0_1 in the cache */
/* replace99_0_0 -> replace24_0_0 in the cache */

/* replace99_0_1 -> replace24_0_0_1 in the cache */
/* replace99_0 -> replace24_0 in the cache */
/* replace99 -> replace96 in the cache */

   /* search100_0_0 -> search1_0_0 in the cache */
/* search100_0 -> search4_0 in the cache */
static const nir_search_expression search100 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search4_0.value },
   NULL,
};

   /* replace100_0_0_0 -> search1_0_0 in the cache */

/* replace100_0_0_1 -> replace25_0_0_1 in the cache */
/* replace100_0_0 -> replace25_0_0 in the cache */

/* replace100_0_1 -> replace25_0_0_1 in the cache */
/* replace100_0 -> replace25_0 in the cache */
/* replace100 -> replace97 in the cache */

   /* search101_0_0 -> search2_0_0 in the cache */
/* search101_0 -> search5_0 in the cache */
static const nir_search_expression search101 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search5_0.value },
   NULL,
};

   /* replace101_0_0_0 -> search2_0_0 in the cache */

/* replace101_0_0_1 -> replace26_0_0_1 in the cache */
/* replace101_0_0 -> replace26_0_0 in the cache */

/* replace101_0_1 -> replace26_0_0_1 in the cache */
/* replace101_0 -> replace26_0 in the cache */
/* replace101 -> replace98 in the cache */

   /* search102_0_0 -> search0_0_0 in the cache */
/* search102_0 -> search54_0 in the cache */
static const nir_search_expression search102 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search54_0.value },
   NULL,
};

   /* replace102_0_0_0 -> search0_0_0 in the cache */

/* replace102_0_0_1 -> replace90_0_1 in the cache */
/* replace102_0_0 -> replace90_0 in the cache */

/* replace102_0_1 -> replace90_1 in the cache */
/* replace102_0 -> replace90 in the cache */
static const nir_search_expression replace102 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 2,
   nir_op_f2f32,
   { &replace90.value },
   NULL,
};

   /* search103_0_0 -> search1_0_0 in the cache */
/* search103_0 -> search55_0 in the cache */
static const nir_search_expression search103 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search55_0.value },
   NULL,
};

   /* replace103_0_0 -> search1_0_0 in the cache */

/* replace103_0_1 -> replace91_0_0_1 in the cache */
/* replace103_0 -> replace91_0_0 in the cache */

/* replace103_1 -> replace91_0_1 in the cache */
/* replace103 -> replace91_0 in the cache */

   /* search104_0_0 -> search2_0_0 in the cache */
/* search104_0 -> search56_0 in the cache */
static const nir_search_expression search104 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search56_0.value },
   NULL,
};

   /* replace104_0_0_0 -> search2_0_0 in the cache */

/* replace104_0_0_1 -> replace92_0_0_1 in the cache */
/* replace104_0_0 -> replace92_0_0 in the cache */

/* replace104_0_1 -> replace92_0_1 in the cache */
/* replace104_0 -> replace92_0 in the cache */
static const nir_search_expression replace104 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 2,
   nir_op_f2f32,
   { &replace92_0.value },
   NULL,
};

   /* search105_0_0 -> search0_0_0 in the cache */
/* search105_0 -> search57_0 in the cache */
static const nir_search_expression search105 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search57_0.value },
   NULL,
};

   /* replace105_0_0_0 -> search0_0_0 in the cache */

/* replace105_0_0_1 -> replace90_0_1 in the cache */
/* replace105_0_0 -> replace90_0 in the cache */

/* replace105_0_1 -> replace90_1 in the cache */
/* replace105_0 -> replace90 in the cache */
/* replace105 -> replace102 in the cache */

   /* search106_0_0 -> search1_0_0 in the cache */
/* search106_0 -> search58_0 in the cache */
static const nir_search_expression search106 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search58_0.value },
   NULL,
};

   /* replace106_0_0 -> search1_0_0 in the cache */

/* replace106_0_1 -> replace91_0_0_1 in the cache */
/* replace106_0 -> replace91_0_0 in the cache */

/* replace106_1 -> replace91_0_1 in the cache */
/* replace106 -> replace91_0 in the cache */

   /* search107_0_0 -> search2_0_0 in the cache */
/* search107_0 -> search59_0 in the cache */
static const nir_search_expression search107 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search59_0.value },
   NULL,
};

   /* replace107_0_0_0 -> search2_0_0 in the cache */

/* replace107_0_0_1 -> replace92_0_0_1 in the cache */
/* replace107_0_0 -> replace92_0_0 in the cache */

/* replace107_0_1 -> replace92_0_1 in the cache */
/* replace107_0 -> replace92_0 in the cache */
/* replace107 -> replace104 in the cache */

   /* search108_0_0 -> search0_0_0 in the cache */
/* search108_0 -> search0_0 in the cache */
static const nir_search_expression search108 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search0_0.value },
   NULL,
};

   /* replace108_0_0_0 -> search0_0_0 in the cache */

/* replace108_0_0_1 -> replace24_0_0_1 in the cache */
/* replace108_0_0 -> replace24_0_0 in the cache */

/* replace108_0_1 -> replace24_0_0_1 in the cache */
/* replace108_0 -> replace24_0 in the cache */
static const nir_search_expression replace108 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &replace24_0.value },
   NULL,
};

   /* search109_0_0 -> search1_0_0 in the cache */
/* search109_0 -> search1_0 in the cache */
static const nir_search_expression search109 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search1_0.value },
   NULL,
};

   /* replace109_0_0_0 -> search1_0_0 in the cache */

/* replace109_0_0_1 -> replace25_0_0_1 in the cache */
/* replace109_0_0 -> replace25_0_0 in the cache */

/* replace109_0_1 -> replace25_0_0_1 in the cache */
/* replace109_0 -> replace25_0 in the cache */
static const nir_search_expression replace109 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &replace25_0.value },
   NULL,
};

   /* search110_0_0 -> search2_0_0 in the cache */
/* search110_0 -> search2_0 in the cache */
static const nir_search_expression search110 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search2_0.value },
   NULL,
};

   /* replace110_0_0_0 -> search2_0_0 in the cache */

/* replace110_0_0_1 -> replace26_0_0_1 in the cache */
/* replace110_0_0 -> replace26_0_0 in the cache */

/* replace110_0_1 -> replace26_0_0_1 in the cache */
/* replace110_0 -> replace26_0 in the cache */
static const nir_search_expression replace110 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &replace26_0.value },
   NULL,
};

   /* search111_0_0 -> search0_0_0 in the cache */
/* search111_0 -> search3_0 in the cache */
static const nir_search_expression search111 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search3_0.value },
   NULL,
};

   /* replace111_0_0_0 -> search0_0_0 in the cache */

/* replace111_0_0_1 -> replace24_0_0_1 in the cache */
/* replace111_0_0 -> replace24_0_0 in the cache */

/* replace111_0_1 -> replace24_0_0_1 in the cache */
/* replace111_0 -> replace24_0 in the cache */
/* replace111 -> replace108 in the cache */

   /* search112_0_0 -> search1_0_0 in the cache */
/* search112_0 -> search4_0 in the cache */
static const nir_search_expression search112 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search4_0.value },
   NULL,
};

   /* replace112_0_0_0 -> search1_0_0 in the cache */

/* replace112_0_0_1 -> replace25_0_0_1 in the cache */
/* replace112_0_0 -> replace25_0_0 in the cache */

/* replace112_0_1 -> replace25_0_0_1 in the cache */
/* replace112_0 -> replace25_0 in the cache */
/* replace112 -> replace109 in the cache */

   /* search113_0_0 -> search2_0_0 in the cache */
/* search113_0 -> search5_0 in the cache */
static const nir_search_expression search113 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search5_0.value },
   NULL,
};

   /* replace113_0_0_0 -> search2_0_0 in the cache */

/* replace113_0_0_1 -> replace26_0_0_1 in the cache */
/* replace113_0_0 -> replace26_0_0 in the cache */

/* replace113_0_1 -> replace26_0_0_1 in the cache */
/* replace113_0 -> replace26_0 in the cache */
/* replace113 -> replace110 in the cache */

   /* search114_0_0 -> search0_0_0 in the cache */
/* search114_0 -> search54_0 in the cache */
static const nir_search_expression search114 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search54_0.value },
   NULL,
};

   /* replace114_0_0_0 -> search0_0_0 in the cache */

/* replace114_0_0_1 -> replace90_0_1 in the cache */
/* replace114_0_0 -> replace90_0 in the cache */

/* replace114_0_1 -> replace90_1 in the cache */
/* replace114_0 -> replace90 in the cache */
static const nir_search_expression replace114 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 2,
   nir_op_f2f64,
   { &replace90.value },
   NULL,
};

   /* search115_0_0 -> search1_0_0 in the cache */
/* search115_0 -> search55_0 in the cache */
static const nir_search_expression search115 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search55_0.value },
   NULL,
};

   /* replace115_0_0_0 -> search1_0_0 in the cache */

/* replace115_0_0_1 -> replace91_0_0_1 in the cache */
/* replace115_0_0 -> replace91_0_0 in the cache */

/* replace115_0_1 -> replace91_0_1 in the cache */
/* replace115_0 -> replace91_0 in the cache */
static const nir_search_expression replace115 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 2,
   nir_op_f2f64,
   { &replace91_0.value },
   NULL,
};

   /* search116_0_0 -> search2_0_0 in the cache */
/* search116_0 -> search56_0 in the cache */
static const nir_search_expression search116 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search56_0.value },
   NULL,
};

   /* replace116_0_0 -> search2_0_0 in the cache */

/* replace116_0_1 -> replace92_0_0_1 in the cache */
/* replace116_0 -> replace92_0_0 in the cache */

/* replace116_1 -> replace92_0_1 in the cache */
/* replace116 -> replace92_0 in the cache */

   /* search117_0_0 -> search0_0_0 in the cache */
/* search117_0 -> search57_0 in the cache */
static const nir_search_expression search117 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search57_0.value },
   NULL,
};

   /* replace117_0_0_0 -> search0_0_0 in the cache */

/* replace117_0_0_1 -> replace90_0_1 in the cache */
/* replace117_0_0 -> replace90_0 in the cache */

/* replace117_0_1 -> replace90_1 in the cache */
/* replace117_0 -> replace90 in the cache */
/* replace117 -> replace114 in the cache */

   /* search118_0_0 -> search1_0_0 in the cache */
/* search118_0 -> search58_0 in the cache */
static const nir_search_expression search118 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search58_0.value },
   NULL,
};

   /* replace118_0_0_0 -> search1_0_0 in the cache */

/* replace118_0_0_1 -> replace91_0_0_1 in the cache */
/* replace118_0_0 -> replace91_0_0 in the cache */

/* replace118_0_1 -> replace91_0_1 in the cache */
/* replace118_0 -> replace91_0 in the cache */
/* replace118 -> replace115 in the cache */

   /* search119_0_0 -> search2_0_0 in the cache */
/* search119_0 -> search59_0 in the cache */
static const nir_search_expression search119 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search59_0.value },
   NULL,
};

   /* replace119_0_0 -> search2_0_0 in the cache */

/* replace119_0_1 -> replace92_0_0_1 in the cache */
/* replace119_0 -> replace92_0_0 in the cache */

/* replace119_1 -> replace92_0_1 in the cache */
/* replace119 -> replace92_0 in the cache */


static const struct transform dxil_nir_lower_8bit_conv_state6_xforms[] = {
  { &search0, &replace0.value, 0 },
  { &search1, &replace1.value, 0 },
  { &search2, &replace2.value, 0 },
  { &search8, &replace8.value, 0 },
  { &search9, &replace1_0.value, 0 },
  { &search10, &replace10.value, 0 },
  { &search16, &replace16.value, 0 },
  { &search17, &replace17.value, 0 },
  { &search18, &replace2_0.value, 0 },
};
static const struct transform dxil_nir_lower_8bit_conv_state7_xforms[] = {
  { &search3, &replace3.value, 0 },
  { &search4, &replace1.value, 0 },
  { &search5, &replace2.value, 0 },
  { &search11, &replace8.value, 0 },
  { &search12, &replace12.value, 0 },
  { &search13, &replace10.value, 0 },
  { &search19, &replace16.value, 0 },
  { &search20, &replace17.value, 0 },
  { &search21, &replace21.value, 0 },
};
static const struct transform dxil_nir_lower_8bit_conv_state8_xforms[] = {
  { &search6, &replace6.value, 0 },
  { &search14, &replace14.value, 0 },
  { &search22, &replace22.value, 0 },
};
static const struct transform dxil_nir_lower_8bit_conv_state9_xforms[] = {
  { &search7, &replace7.value, 0 },
  { &search15, &replace15.value, 0 },
  { &search23, &replace23.value, 0 },
};
static const struct transform dxil_nir_lower_8bit_conv_state10_xforms[] = {
  { &search24, &replace24.value, 0 },
  { &search25, &replace25.value, 0 },
  { &search26, &replace26.value, 0 },
  { &search32, &replace32.value, 0 },
  { &search33, &replace33.value, 0 },
  { &search34, &replace34.value, 0 },
  { &search40, &replace40.value, 0 },
  { &search41, &replace41.value, 0 },
  { &search42, &replace42.value, 0 },
};
static const struct transform dxil_nir_lower_8bit_conv_state11_xforms[] = {
  { &search27, &replace24_0.value, 0 },
  { &search28, &replace25.value, 0 },
  { &search29, &replace26.value, 0 },
  { &search35, &replace32.value, 0 },
  { &search36, &replace25_0.value, 0 },
  { &search37, &replace34.value, 0 },
  { &search43, &replace40.value, 0 },
  { &search44, &replace41.value, 0 },
  { &search45, &replace26_0.value, 0 },
};
static const struct transform dxil_nir_lower_8bit_conv_state12_xforms[] = {
  { &search30, &replace30.value, 0 },
  { &search38, &replace38.value, 0 },
  { &search46, &replace46.value, 0 },
};
static const struct transform dxil_nir_lower_8bit_conv_state13_xforms[] = {
  { &search31, &replace31.value, 0 },
  { &search39, &replace39.value, 0 },
  { &search47, &replace47.value, 0 },
};
static const struct transform dxil_nir_lower_8bit_conv_state14_xforms[] = {
  { &search48, &replace48.value, 0 },
  { &search49, &replace49.value, 0 },
  { &search50, &replace50.value, 0 },
  { &search60, &replace60.value, 0 },
  { &search61, &replace61.value, 0 },
  { &search62, &replace62.value, 0 },
  { &search72, &replace72.value, 0 },
  { &search73, &replace73.value, 0 },
  { &search74, &replace74.value, 0 },
};
static const struct transform dxil_nir_lower_8bit_conv_state15_xforms[] = {
  { &search51, &replace48.value, 0 },
  { &search52, &replace49.value, 0 },
  { &search53, &replace50.value, 0 },
  { &search63, &replace60.value, 0 },
  { &search64, &replace61.value, 0 },
  { &search65, &replace62.value, 0 },
  { &search75, &replace72.value, 0 },
  { &search76, &replace73.value, 0 },
  { &search77, &replace74.value, 0 },
};
static const struct transform dxil_nir_lower_8bit_conv_state16_xforms[] = {
  { &search54, &replace54.value, 0 },
  { &search55, &replace55.value, 0 },
  { &search56, &replace56.value, 0 },
  { &search66, &replace66.value, 0 },
  { &search67, &replace55_0.value, 0 },
  { &search68, &replace68.value, 0 },
  { &search78, &replace78.value, 0 },
  { &search79, &replace79.value, 0 },
  { &search80, &replace56_0.value, 0 },
};
static const struct transform dxil_nir_lower_8bit_conv_state17_xforms[] = {
  { &search57, &replace54.value, 0 },
  { &search58, &replace55.value, 0 },
  { &search59, &replace56.value, 0 },
  { &search69, &replace66.value, 0 },
  { &search70, &replace55_0.value, 0 },
  { &search71, &replace68.value, 0 },
  { &search81, &replace78.value, 0 },
  { &search82, &replace79.value, 0 },
  { &search83, &replace56_0.value, 0 },
};
static const struct transform dxil_nir_lower_8bit_conv_state18_xforms[] = {
  { &search84, &replace84.value, 0 },
  { &search85, &replace85.value, 0 },
  { &search86, &replace86.value, 0 },
  { &search96, &replace96.value, 0 },
  { &search97, &replace97.value, 0 },
  { &search98, &replace98.value, 0 },
  { &search108, &replace108.value, 0 },
  { &search109, &replace109.value, 0 },
  { &search110, &replace110.value, 0 },
};
static const struct transform dxil_nir_lower_8bit_conv_state19_xforms[] = {
  { &search87, &replace84.value, 0 },
  { &search88, &replace85.value, 0 },
  { &search89, &replace86.value, 0 },
  { &search99, &replace96.value, 0 },
  { &search100, &replace97.value, 0 },
  { &search101, &replace98.value, 0 },
  { &search111, &replace108.value, 0 },
  { &search112, &replace109.value, 0 },
  { &search113, &replace110.value, 0 },
};
static const struct transform dxil_nir_lower_8bit_conv_state20_xforms[] = {
  { &search90, &replace90.value, 0 },
  { &search91, &replace91.value, 0 },
  { &search92, &replace92.value, 0 },
  { &search102, &replace102.value, 0 },
  { &search103, &replace91_0.value, 0 },
  { &search104, &replace104.value, 0 },
  { &search114, &replace114.value, 0 },
  { &search115, &replace115.value, 0 },
  { &search116, &replace92_0.value, 0 },
};
static const struct transform dxil_nir_lower_8bit_conv_state21_xforms[] = {
  { &search93, &replace90.value, 0 },
  { &search94, &replace91.value, 0 },
  { &search95, &replace92.value, 0 },
  { &search105, &replace102.value, 0 },
  { &search106, &replace91_0.value, 0 },
  { &search107, &replace104.value, 0 },
  { &search117, &replace114.value, 0 },
  { &search118, &replace115.value, 0 },
  { &search119, &replace92_0.value, 0 },
};

static const struct per_op_table dxil_nir_lower_8bit_conv_table[nir_num_search_ops] = {
   [nir_search_op_u2u] = {
      .filter = (uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         2,
         6,
         7,
         8,
         9,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         3,
         10,
         11,
         12,
         13,
      },
   },
   [nir_search_op_f2u] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         4,
      },
   },
   [nir_search_op_f2i] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         5,
      },
   },
   [nir_search_op_u2f] = {
      .filter = (uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         0,
         14,
         15,
         16,
         17,
      },
   },
   [nir_search_op_i2f] = {
      .filter = (uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         0,
         18,
         19,
         20,
         21,
      },
   },
};

const struct transform *dxil_nir_lower_8bit_conv_transforms[] = {
   NULL,
   NULL,
   NULL,
   NULL,
   NULL,
   NULL,
   dxil_nir_lower_8bit_conv_state6_xforms,
   dxil_nir_lower_8bit_conv_state7_xforms,
   dxil_nir_lower_8bit_conv_state8_xforms,
   dxil_nir_lower_8bit_conv_state9_xforms,
   dxil_nir_lower_8bit_conv_state10_xforms,
   dxil_nir_lower_8bit_conv_state11_xforms,
   dxil_nir_lower_8bit_conv_state12_xforms,
   dxil_nir_lower_8bit_conv_state13_xforms,
   dxil_nir_lower_8bit_conv_state14_xforms,
   dxil_nir_lower_8bit_conv_state15_xforms,
   dxil_nir_lower_8bit_conv_state16_xforms,
   dxil_nir_lower_8bit_conv_state17_xforms,
   dxil_nir_lower_8bit_conv_state18_xforms,
   dxil_nir_lower_8bit_conv_state19_xforms,
   dxil_nir_lower_8bit_conv_state20_xforms,
   dxil_nir_lower_8bit_conv_state21_xforms,
};

const uint16_t dxil_nir_lower_8bit_conv_transform_counts[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state6_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state7_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state8_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state9_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state10_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state11_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state12_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state13_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state14_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state15_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state16_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state17_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state18_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state19_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state20_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_8bit_conv_state21_xforms),
};

bool
dxil_nir_lower_8bit_conv(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[1];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   condition_flags[0] = true;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        dxil_nir_lower_8bit_conv_transforms,
                                        dxil_nir_lower_8bit_conv_transform_counts,
                                        dxil_nir_lower_8bit_conv_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 58
 * transforms:
 *    ('u2u32', ('u2u16', 'a@32')) => ('iand', 'a', 65535)
 *    ('u2u32', ('u2u16', 'a@64')) => ('u2u32', ('iand', 'a', 65535))
 *    ('u2u32', ('i2i16', 'a@32')) => ('u2u32', ('iand', 'a', 65535))
 *    ('u2u32', ('i2i16', 'a@64')) => ('u2u32', ('iand', 'a', 65535))
 *    ('u2u32', ('f2u16', 'a')) => ('iand', ('f2u32', 'a'), 65535)
 *    ('u2u32', ('f2i16', 'a')) => ('iand', ('f2i32', 'a'), 65535)
 *    ('u2u64', ('u2u16', 'a@32')) => ('u2u64', ('iand', 'a', 65535))
 *    ('u2u64', ('u2u16', 'a@64')) => ('iand', 'a', 65535)
 *    ('u2u64', ('i2i16', 'a@32')) => ('u2u64', ('iand', 'a', 65535))
 *    ('u2u64', ('i2i16', 'a@64')) => ('u2u64', ('iand', 'a', 65535))
 *    ('u2u64', ('f2u16', 'a')) => ('iand', ('f2u64', 'a'), 65535)
 *    ('u2u64', ('f2i16', 'a')) => ('iand', ('f2i64', 'a'), 65535)
 *    ('i2i32', ('u2u16', 'a@32')) => ('i2i32', ('ishr', ('ishl', 'a', 16), 16))
 *    ('i2i32', ('u2u16', 'a@64')) => ('i2i32', ('ishr', ('ishl', 'a', 48), 48))
 *    ('i2i32', ('i2i16', 'a@32')) => ('ishr', ('ishl', 'a', 16), 16)
 *    ('i2i32', ('i2i16', 'a@64')) => ('i2i32', ('ishr', ('ishl', 'a', 48), 48))
 *    ('i2i32', ('f2u16', 'a')) => ('ishr', ('ishl', ('f2u32', 'a'), 16), 16)
 *    ('i2i32', ('f2i16', 'a')) => ('ishr', ('ishl', ('f2i32', 'a'), 16), 16)
 *    ('i2i64', ('u2u16', 'a@32')) => ('i2i64', ('ishr', ('ishl', 'a', 16), 16))
 *    ('i2i64', ('u2u16', 'a@64')) => ('i2i64', ('ishr', ('ishl', 'a', 48), 48))
 *    ('i2i64', ('i2i16', 'a@32')) => ('i2i64', ('ishr', ('ishl', 'a', 16), 16))
 *    ('i2i64', ('i2i16', 'a@64')) => ('ishr', ('ishl', 'a', 48), 48)
 *    ('i2i64', ('f2u16', 'a')) => ('ishr', ('ishl', ('f2u64', 'a'), 48), 48)
 *    ('i2i64', ('f2i16', 'a')) => ('ishr', ('ishl', ('f2i64', 'a'), 48), 48)
 *    ('u2f32', ('u2u16', 'a@32')) => ('u2f32', ('iand', 'a', 65535))
 *    ('u2f32', ('u2u16', 'a@64')) => ('u2f32', ('iand', 'a', 65535))
 *    ('u2f32', ('i2i16', 'a@32')) => ('u2f32', ('iand', 'a', 65535))
 *    ('u2f32', ('i2i16', 'a@64')) => ('u2f32', ('iand', 'a', 65535))
 *    ('u2f32', ('f2u16', 'a@32')) => ('fmin', ('fmax', 'a', 0.0), 65535.0)
 *    ('u2f32', ('f2u16', 'a@64')) => ('f2f32', ('fmin', ('fmax', 'a', 0.0), 65535.0))
 *    ('u2f32', ('f2i16', 'a@32')) => ('fmin', ('fmax', 'a', 0.0), 65535.0)
 *    ('u2f32', ('f2i16', 'a@64')) => ('f2f32', ('fmin', ('fmax', 'a', 0.0), 65535.0))
 *    ('u2f64', ('u2u16', 'a@32')) => ('u2f64', ('iand', 'a', 65535))
 *    ('u2f64', ('u2u16', 'a@64')) => ('u2f64', ('iand', 'a', 65535))
 *    ('u2f64', ('i2i16', 'a@32')) => ('u2f64', ('iand', 'a', 65535))
 *    ('u2f64', ('i2i16', 'a@64')) => ('u2f64', ('iand', 'a', 65535))
 *    ('u2f64', ('f2u16', 'a@32')) => ('f2f64', ('fmin', ('fmax', 'a', 0.0), 65535.0))
 *    ('u2f64', ('f2u16', 'a@64')) => ('fmin', ('fmax', 'a', 0.0), 65535.0)
 *    ('u2f64', ('f2i16', 'a@32')) => ('f2f64', ('fmin', ('fmax', 'a', 0.0), 65535.0))
 *    ('u2f64', ('f2i16', 'a@64')) => ('fmin', ('fmax', 'a', 0.0), 65535.0)
 *    ('i2f32', ('u2u16', 'a@32')) => ('i2f32', ('ishr', ('ishl', 'a', 16), 16))
 *    ('i2f32', ('u2u16', 'a@64')) => ('i2f32', ('ishr', ('ishl', 'a', 48), 48))
 *    ('i2f32', ('i2i16', 'a@32')) => ('i2f32', ('ishr', ('ishl', 'a', 16), 16))
 *    ('i2f32', ('i2i16', 'a@64')) => ('i2f32', ('ishr', ('ishl', 'a', 48), 48))
 *    ('i2f32', ('f2u16', 'a@32')) => ('fmin', ('fmax', 'a', -32768.0), 32767.0)
 *    ('i2f32', ('f2u16', 'a@64')) => ('f2f32', ('fmin', ('fmax', 'a', -32768.0), 32767.0))
 *    ('i2f32', ('f2i16', 'a@32')) => ('fmin', ('fmax', 'a', -32768.0), 32767.0)
 *    ('i2f32', ('f2i16', 'a@64')) => ('f2f32', ('fmin', ('fmax', 'a', -32768.0), 32767.0))
 *    ('i2f64', ('u2u16', 'a@32')) => ('i2f64', ('ishr', ('ishl', 'a', 16), 16))
 *    ('i2f64', ('u2u16', 'a@64')) => ('i2f64', ('ishr', ('ishl', 'a', 48), 48))
 *    ('i2f64', ('i2i16', 'a@32')) => ('i2f64', ('ishr', ('ishl', 'a', 16), 16))
 *    ('i2f64', ('i2i16', 'a@64')) => ('i2f64', ('ishr', ('ishl', 'a', 48), 48))
 *    ('i2f64', ('f2u16', 'a@32')) => ('f2f64', ('fmin', ('fmax', 'a', -32768.0), 32767.0))
 *    ('i2f64', ('f2u16', 'a@64')) => ('fmin', ('fmax', 'a', -32768.0), 32767.0)
 *    ('i2f64', ('f2i16', 'a@32')) => ('f2f64', ('fmin', ('fmax', 'a', -32768.0), 32767.0))
 *    ('i2f64', ('f2i16', 'a@64')) => ('fmin', ('fmax', 'a', -32768.0), 32767.0)
 *    ('f2f32', ('u2u16', 'a@32')) => ('unpack_half_2x16_split_x', 'a')
 *    ('u2u32', ('f2f16_rtz', 'a@32')) => ('pack_half_2x16_split', 'a', 0)
 */


   static const nir_search_variable search120_0_0 = {
   { nir_search_value_variable, 32 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
};
static const nir_search_expression search120_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2u16,
   { &search120_0_0.value },
   NULL,
};
static const nir_search_expression search120 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2u32,
   { &search120_0.value },
   NULL,
};

   /* replace120_0 -> search120_0_0 in the cache */

static const nir_search_constant replace120_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xffff /* 65535 */ },
};
static const nir_search_expression replace120 = {
   { nir_search_value_expression, 32 },
   false, false,
   0, 1,
   nir_op_iand,
   { &search120_0_0.value, &replace120_1.value },
   NULL,
};

   static const nir_search_variable search121_0_0 = {
   { nir_search_value_variable, 64 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
};
static const nir_search_expression search121_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_u2u16,
   { &search121_0_0.value },
   NULL,
};
static const nir_search_expression search121 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2u32,
   { &search121_0.value },
   NULL,
};

   /* replace121_0_0 -> search121_0_0 in the cache */

static const nir_search_constant replace121_0_1 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0xffff /* 65535 */ },
};
static const nir_search_expression replace121_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   0, 1,
   nir_op_iand,
   { &search121_0_0.value, &replace121_0_1.value },
   NULL,
};
static const nir_search_expression replace121 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 1,
   nir_op_u2u32,
   { &replace121_0.value },
   NULL,
};

   /* search122_0_0 -> search120_0_0 in the cache */
static const nir_search_expression search122_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2i16,
   { &search120_0_0.value },
   NULL,
};
static const nir_search_expression search122 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2u32,
   { &search122_0.value },
   NULL,
};

   /* replace122_0_0 -> search120_0_0 in the cache */

/* replace122_0_1 -> replace120_1 in the cache */
/* replace122_0 -> replace120 in the cache */
static const nir_search_expression replace122 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 1,
   nir_op_u2u32,
   { &replace120.value },
   NULL,
};

   /* search123_0_0 -> search121_0_0 in the cache */
static const nir_search_expression search123_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_i2i16,
   { &search121_0_0.value },
   NULL,
};
static const nir_search_expression search123 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2u32,
   { &search123_0.value },
   NULL,
};

   /* replace123_0_0 -> search121_0_0 in the cache */

/* replace123_0_1 -> replace121_0_1 in the cache */
/* replace123_0 -> replace121_0 in the cache */
/* replace123 -> replace121 in the cache */

   static const nir_search_variable search124_0_0 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
};
static const nir_search_expression search124_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_f2u16,
   { &search124_0_0.value },
   NULL,
};
static const nir_search_expression search124 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2u32,
   { &search124_0.value },
   NULL,
};

   /* replace124_0_0 -> search124_0_0 in the cache */
static const nir_search_expression replace124_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_f2u32,
   { &search124_0_0.value },
   NULL,
};

/* replace124_1 -> replace120_1 in the cache */
static const nir_search_expression replace124 = {
   { nir_search_value_expression, 32 },
   false, false,
   0, 1,
   nir_op_iand,
   { &replace124_0.value, &replace120_1.value },
   NULL,
};

   /* search125_0_0 -> search124_0_0 in the cache */
static const nir_search_expression search125_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_f2i16,
   { &search124_0_0.value },
   NULL,
};
static const nir_search_expression search125 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2u32,
   { &search125_0.value },
   NULL,
};

   /* replace125_0_0 -> search124_0_0 in the cache */
static const nir_search_expression replace125_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_f2i32,
   { &search124_0_0.value },
   NULL,
};

/* replace125_1 -> replace120_1 in the cache */
static const nir_search_expression replace125 = {
   { nir_search_value_expression, 32 },
   false, false,
   0, 1,
   nir_op_iand,
   { &replace125_0.value, &replace120_1.value },
   NULL,
};

   /* search126_0_0 -> search120_0_0 in the cache */
/* search126_0 -> search120_0 in the cache */
static const nir_search_expression search126 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2u64,
   { &search120_0.value },
   NULL,
};

   /* replace126_0_0 -> search120_0_0 in the cache */

/* replace126_0_1 -> replace120_1 in the cache */
/* replace126_0 -> replace120 in the cache */
static const nir_search_expression replace126 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 1,
   nir_op_u2u64,
   { &replace120.value },
   NULL,
};

   /* search127_0_0 -> search121_0_0 in the cache */
/* search127_0 -> search121_0 in the cache */
static const nir_search_expression search127 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2u64,
   { &search121_0.value },
   NULL,
};

   /* replace127_0 -> search121_0_0 in the cache */

/* replace127_1 -> replace121_0_1 in the cache */
/* replace127 -> replace121_0 in the cache */

   /* search128_0_0 -> search120_0_0 in the cache */
/* search128_0 -> search122_0 in the cache */
static const nir_search_expression search128 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2u64,
   { &search122_0.value },
   NULL,
};

   /* replace128_0_0 -> search120_0_0 in the cache */

/* replace128_0_1 -> replace120_1 in the cache */
/* replace128_0 -> replace120 in the cache */
/* replace128 -> replace126 in the cache */

   /* search129_0_0 -> search121_0_0 in the cache */
/* search129_0 -> search123_0 in the cache */
static const nir_search_expression search129 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2u64,
   { &search123_0.value },
   NULL,
};

   /* replace129_0_0 -> search121_0_0 in the cache */

/* replace129_0_1 -> replace121_0_1 in the cache */
/* replace129_0 -> replace121_0 in the cache */
static const nir_search_expression replace129 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 1,
   nir_op_u2u64,
   { &replace121_0.value },
   NULL,
};

   /* search130_0_0 -> search124_0_0 in the cache */
/* search130_0 -> search124_0 in the cache */
static const nir_search_expression search130 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2u64,
   { &search124_0.value },
   NULL,
};

   /* replace130_0_0 -> search124_0_0 in the cache */
static const nir_search_expression replace130_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_f2u64,
   { &search124_0_0.value },
   NULL,
};

/* replace130_1 -> replace121_0_1 in the cache */
static const nir_search_expression replace130 = {
   { nir_search_value_expression, 64 },
   false, false,
   0, 1,
   nir_op_iand,
   { &replace130_0.value, &replace121_0_1.value },
   NULL,
};

   /* search131_0_0 -> search124_0_0 in the cache */
/* search131_0 -> search125_0 in the cache */
static const nir_search_expression search131 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2u64,
   { &search125_0.value },
   NULL,
};

   /* replace131_0_0 -> search124_0_0 in the cache */
static const nir_search_expression replace131_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_f2i64,
   { &search124_0_0.value },
   NULL,
};

/* replace131_1 -> replace121_0_1 in the cache */
static const nir_search_expression replace131 = {
   { nir_search_value_expression, 64 },
   false, false,
   0, 1,
   nir_op_iand,
   { &replace131_0.value, &replace121_0_1.value },
   NULL,
};

   /* search132_0_0 -> search120_0_0 in the cache */
/* search132_0 -> search120_0 in the cache */
static const nir_search_expression search132 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &search120_0.value },
   NULL,
};

   /* replace132_0_0_0 -> search120_0_0 in the cache */

static const nir_search_constant replace132_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x10 /* 16 */ },
};
static const nir_search_expression replace132_0_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_ishl,
   { &search120_0_0.value, &replace132_0_0_1.value },
   NULL,
};

/* replace132_0_1 -> replace132_0_0_1 in the cache */
static const nir_search_expression replace132_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_ishr,
   { &replace132_0_0.value, &replace132_0_0_1.value },
   NULL,
};
static const nir_search_expression replace132 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &replace132_0.value },
   NULL,
};

   /* search133_0_0 -> search121_0_0 in the cache */
/* search133_0 -> search121_0 in the cache */
static const nir_search_expression search133 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &search121_0.value },
   NULL,
};

   /* replace133_0_0_0 -> search121_0_0 in the cache */

static const nir_search_constant replace133_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x30 /* 48 */ },
};
static const nir_search_expression replace133_0_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_ishl,
   { &search121_0_0.value, &replace133_0_0_1.value },
   NULL,
};

/* replace133_0_1 -> replace133_0_0_1 in the cache */
static const nir_search_expression replace133_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_ishr,
   { &replace133_0_0.value, &replace133_0_0_1.value },
   NULL,
};
static const nir_search_expression replace133 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &replace133_0.value },
   NULL,
};

   /* search134_0_0 -> search120_0_0 in the cache */
/* search134_0 -> search122_0 in the cache */
static const nir_search_expression search134 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &search122_0.value },
   NULL,
};

   /* replace134_0_0 -> search120_0_0 in the cache */

/* replace134_0_1 -> replace132_0_0_1 in the cache */
/* replace134_0 -> replace132_0_0 in the cache */

/* replace134_1 -> replace132_0_0_1 in the cache */
/* replace134 -> replace132_0 in the cache */

   /* search135_0_0 -> search121_0_0 in the cache */
/* search135_0 -> search123_0 in the cache */
static const nir_search_expression search135 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &search123_0.value },
   NULL,
};

   /* replace135_0_0_0 -> search121_0_0 in the cache */

/* replace135_0_0_1 -> replace133_0_0_1 in the cache */
/* replace135_0_0 -> replace133_0_0 in the cache */

/* replace135_0_1 -> replace133_0_0_1 in the cache */
/* replace135_0 -> replace133_0 in the cache */
/* replace135 -> replace133 in the cache */

   /* search136_0_0 -> search124_0_0 in the cache */
/* search136_0 -> search124_0 in the cache */
static const nir_search_expression search136 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &search124_0.value },
   NULL,
};

   /* replace136_0_0_0 -> search124_0_0 in the cache */
/* replace136_0_0 -> replace124_0 in the cache */

/* replace136_0_1 -> replace132_0_0_1 in the cache */
static const nir_search_expression replace136_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_ishl,
   { &replace124_0.value, &replace132_0_0_1.value },
   NULL,
};

/* replace136_1 -> replace132_0_0_1 in the cache */
static const nir_search_expression replace136 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_ishr,
   { &replace136_0.value, &replace132_0_0_1.value },
   NULL,
};

   /* search137_0_0 -> search124_0_0 in the cache */
/* search137_0 -> search125_0 in the cache */
static const nir_search_expression search137 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2i32,
   { &search125_0.value },
   NULL,
};

   /* replace137_0_0_0 -> search124_0_0 in the cache */
/* replace137_0_0 -> replace125_0 in the cache */

/* replace137_0_1 -> replace132_0_0_1 in the cache */
static const nir_search_expression replace137_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_ishl,
   { &replace125_0.value, &replace132_0_0_1.value },
   NULL,
};

/* replace137_1 -> replace132_0_0_1 in the cache */
static const nir_search_expression replace137 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_ishr,
   { &replace137_0.value, &replace132_0_0_1.value },
   NULL,
};

   /* search138_0_0 -> search120_0_0 in the cache */
/* search138_0 -> search120_0 in the cache */
static const nir_search_expression search138 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &search120_0.value },
   NULL,
};

   /* replace138_0_0_0 -> search120_0_0 in the cache */

/* replace138_0_0_1 -> replace132_0_0_1 in the cache */
/* replace138_0_0 -> replace132_0_0 in the cache */

/* replace138_0_1 -> replace132_0_0_1 in the cache */
/* replace138_0 -> replace132_0 in the cache */
static const nir_search_expression replace138 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &replace132_0.value },
   NULL,
};

   /* search139_0_0 -> search121_0_0 in the cache */
/* search139_0 -> search121_0 in the cache */
static const nir_search_expression search139 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &search121_0.value },
   NULL,
};

   /* replace139_0_0_0 -> search121_0_0 in the cache */

/* replace139_0_0_1 -> replace133_0_0_1 in the cache */
/* replace139_0_0 -> replace133_0_0 in the cache */

/* replace139_0_1 -> replace133_0_0_1 in the cache */
/* replace139_0 -> replace133_0 in the cache */
static const nir_search_expression replace139 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &replace133_0.value },
   NULL,
};

   /* search140_0_0 -> search120_0_0 in the cache */
/* search140_0 -> search122_0 in the cache */
static const nir_search_expression search140 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &search122_0.value },
   NULL,
};

   /* replace140_0_0_0 -> search120_0_0 in the cache */

/* replace140_0_0_1 -> replace132_0_0_1 in the cache */
/* replace140_0_0 -> replace132_0_0 in the cache */

/* replace140_0_1 -> replace132_0_0_1 in the cache */
/* replace140_0 -> replace132_0 in the cache */
/* replace140 -> replace138 in the cache */

   /* search141_0_0 -> search121_0_0 in the cache */
/* search141_0 -> search123_0 in the cache */
static const nir_search_expression search141 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &search123_0.value },
   NULL,
};

   /* replace141_0_0 -> search121_0_0 in the cache */

/* replace141_0_1 -> replace133_0_0_1 in the cache */
/* replace141_0 -> replace133_0_0 in the cache */

/* replace141_1 -> replace133_0_0_1 in the cache */
/* replace141 -> replace133_0 in the cache */

   /* search142_0_0 -> search124_0_0 in the cache */
/* search142_0 -> search124_0 in the cache */
static const nir_search_expression search142 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &search124_0.value },
   NULL,
};

   /* replace142_0_0_0 -> search124_0_0 in the cache */
/* replace142_0_0 -> replace130_0 in the cache */

/* replace142_0_1 -> replace133_0_0_1 in the cache */
static const nir_search_expression replace142_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_ishl,
   { &replace130_0.value, &replace133_0_0_1.value },
   NULL,
};

/* replace142_1 -> replace133_0_0_1 in the cache */
static const nir_search_expression replace142 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_ishr,
   { &replace142_0.value, &replace133_0_0_1.value },
   NULL,
};

   /* search143_0_0 -> search124_0_0 in the cache */
/* search143_0 -> search125_0 in the cache */
static const nir_search_expression search143 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2i64,
   { &search125_0.value },
   NULL,
};

   /* replace143_0_0_0 -> search124_0_0 in the cache */
/* replace143_0_0 -> replace131_0 in the cache */

/* replace143_0_1 -> replace133_0_0_1 in the cache */
static const nir_search_expression replace143_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_ishl,
   { &replace131_0.value, &replace133_0_0_1.value },
   NULL,
};

/* replace143_1 -> replace133_0_0_1 in the cache */
static const nir_search_expression replace143 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_ishr,
   { &replace143_0.value, &replace133_0_0_1.value },
   NULL,
};

   /* search144_0_0 -> search120_0_0 in the cache */
/* search144_0 -> search120_0 in the cache */
static const nir_search_expression search144 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search120_0.value },
   NULL,
};

   /* replace144_0_0 -> search120_0_0 in the cache */

/* replace144_0_1 -> replace120_1 in the cache */
/* replace144_0 -> replace120 in the cache */
static const nir_search_expression replace144 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 1,
   nir_op_u2f32,
   { &replace120.value },
   NULL,
};

   /* search145_0_0 -> search121_0_0 in the cache */
/* search145_0 -> search121_0 in the cache */
static const nir_search_expression search145 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search121_0.value },
   NULL,
};

   /* replace145_0_0 -> search121_0_0 in the cache */

/* replace145_0_1 -> replace121_0_1 in the cache */
/* replace145_0 -> replace121_0 in the cache */
static const nir_search_expression replace145 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 1,
   nir_op_u2f32,
   { &replace121_0.value },
   NULL,
};

   /* search146_0_0 -> search120_0_0 in the cache */
/* search146_0 -> search122_0 in the cache */
static const nir_search_expression search146 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search122_0.value },
   NULL,
};

   /* replace146_0_0 -> search120_0_0 in the cache */

/* replace146_0_1 -> replace120_1 in the cache */
/* replace146_0 -> replace120 in the cache */
/* replace146 -> replace144 in the cache */

   /* search147_0_0 -> search121_0_0 in the cache */
/* search147_0 -> search123_0 in the cache */
static const nir_search_expression search147 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search123_0.value },
   NULL,
};

   /* replace147_0_0 -> search121_0_0 in the cache */

/* replace147_0_1 -> replace121_0_1 in the cache */
/* replace147_0 -> replace121_0 in the cache */
/* replace147 -> replace145 in the cache */

   /* search148_0_0 -> search120_0_0 in the cache */
static const nir_search_expression search148_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_f2u16,
   { &search120_0_0.value },
   NULL,
};
static const nir_search_expression search148 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search148_0.value },
   NULL,
};

   /* replace148_0_0 -> search120_0_0 in the cache */

static const nir_search_constant replace148_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x0 /* 0.0 */ },
};
static const nir_search_expression replace148_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   1, 1,
   nir_op_fmax,
   { &search120_0_0.value, &replace148_0_1.value },
   NULL,
};

static const nir_search_constant replace148_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x40efffe000000000 /* 65535.0 */ },
};
static const nir_search_expression replace148 = {
   { nir_search_value_expression, 32 },
   false, false,
   0, 2,
   nir_op_fmin,
   { &replace148_0.value, &replace148_1.value },
   NULL,
};

   /* search149_0_0 -> search121_0_0 in the cache */
static const nir_search_expression search149_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_f2u16,
   { &search121_0_0.value },
   NULL,
};
static const nir_search_expression search149 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search149_0.value },
   NULL,
};

   /* replace149_0_0_0 -> search121_0_0 in the cache */

static const nir_search_constant replace149_0_0_1 = {
   { nir_search_value_constant, 64 },
   nir_type_float, { 0x0 /* 0.0 */ },
};
static const nir_search_expression replace149_0_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   1, 1,
   nir_op_fmax,
   { &search121_0_0.value, &replace149_0_0_1.value },
   NULL,
};

static const nir_search_constant replace149_0_1 = {
   { nir_search_value_constant, 64 },
   nir_type_float, { 0x40efffe000000000 /* 65535.0 */ },
};
static const nir_search_expression replace149_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   0, 2,
   nir_op_fmin,
   { &replace149_0_0.value, &replace149_0_1.value },
   NULL,
};
static const nir_search_expression replace149 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 2,
   nir_op_f2f32,
   { &replace149_0.value },
   NULL,
};

   /* search150_0_0 -> search120_0_0 in the cache */
static const nir_search_expression search150_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_f2i16,
   { &search120_0_0.value },
   NULL,
};
static const nir_search_expression search150 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search150_0.value },
   NULL,
};

   /* replace150_0_0 -> search120_0_0 in the cache */

/* replace150_0_1 -> replace148_0_1 in the cache */
/* replace150_0 -> replace148_0 in the cache */

/* replace150_1 -> replace148_1 in the cache */
/* replace150 -> replace148 in the cache */

   /* search151_0_0 -> search121_0_0 in the cache */
static const nir_search_expression search151_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_f2i16,
   { &search121_0_0.value },
   NULL,
};
static const nir_search_expression search151 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2f32,
   { &search151_0.value },
   NULL,
};

   /* replace151_0_0_0 -> search121_0_0 in the cache */

/* replace151_0_0_1 -> replace149_0_0_1 in the cache */
/* replace151_0_0 -> replace149_0_0 in the cache */

/* replace151_0_1 -> replace149_0_1 in the cache */
/* replace151_0 -> replace149_0 in the cache */
/* replace151 -> replace149 in the cache */

   /* search152_0_0 -> search120_0_0 in the cache */
/* search152_0 -> search120_0 in the cache */
static const nir_search_expression search152 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search120_0.value },
   NULL,
};

   /* replace152_0_0 -> search120_0_0 in the cache */

/* replace152_0_1 -> replace120_1 in the cache */
/* replace152_0 -> replace120 in the cache */
static const nir_search_expression replace152 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 1,
   nir_op_u2f64,
   { &replace120.value },
   NULL,
};

   /* search153_0_0 -> search121_0_0 in the cache */
/* search153_0 -> search121_0 in the cache */
static const nir_search_expression search153 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search121_0.value },
   NULL,
};

   /* replace153_0_0 -> search121_0_0 in the cache */

/* replace153_0_1 -> replace121_0_1 in the cache */
/* replace153_0 -> replace121_0 in the cache */
static const nir_search_expression replace153 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 1,
   nir_op_u2f64,
   { &replace121_0.value },
   NULL,
};

   /* search154_0_0 -> search120_0_0 in the cache */
/* search154_0 -> search122_0 in the cache */
static const nir_search_expression search154 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search122_0.value },
   NULL,
};

   /* replace154_0_0 -> search120_0_0 in the cache */

/* replace154_0_1 -> replace120_1 in the cache */
/* replace154_0 -> replace120 in the cache */
/* replace154 -> replace152 in the cache */

   /* search155_0_0 -> search121_0_0 in the cache */
/* search155_0 -> search123_0 in the cache */
static const nir_search_expression search155 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search123_0.value },
   NULL,
};

   /* replace155_0_0 -> search121_0_0 in the cache */

/* replace155_0_1 -> replace121_0_1 in the cache */
/* replace155_0 -> replace121_0 in the cache */
/* replace155 -> replace153 in the cache */

   /* search156_0_0 -> search120_0_0 in the cache */
/* search156_0 -> search148_0 in the cache */
static const nir_search_expression search156 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search148_0.value },
   NULL,
};

   /* replace156_0_0_0 -> search120_0_0 in the cache */

/* replace156_0_0_1 -> replace148_0_1 in the cache */
/* replace156_0_0 -> replace148_0 in the cache */

/* replace156_0_1 -> replace148_1 in the cache */
/* replace156_0 -> replace148 in the cache */
static const nir_search_expression replace156 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 2,
   nir_op_f2f64,
   { &replace148.value },
   NULL,
};

   /* search157_0_0 -> search121_0_0 in the cache */
/* search157_0 -> search149_0 in the cache */
static const nir_search_expression search157 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search149_0.value },
   NULL,
};

   /* replace157_0_0 -> search121_0_0 in the cache */

/* replace157_0_1 -> replace149_0_0_1 in the cache */
/* replace157_0 -> replace149_0_0 in the cache */

/* replace157_1 -> replace149_0_1 in the cache */
/* replace157 -> replace149_0 in the cache */

   /* search158_0_0 -> search120_0_0 in the cache */
/* search158_0 -> search150_0 in the cache */
static const nir_search_expression search158 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search150_0.value },
   NULL,
};

   /* replace158_0_0_0 -> search120_0_0 in the cache */

/* replace158_0_0_1 -> replace148_0_1 in the cache */
/* replace158_0_0 -> replace148_0 in the cache */

/* replace158_0_1 -> replace148_1 in the cache */
/* replace158_0 -> replace148 in the cache */
/* replace158 -> replace156 in the cache */

   /* search159_0_0 -> search121_0_0 in the cache */
/* search159_0 -> search151_0 in the cache */
static const nir_search_expression search159 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_u2f64,
   { &search151_0.value },
   NULL,
};

   /* replace159_0_0 -> search121_0_0 in the cache */

/* replace159_0_1 -> replace149_0_0_1 in the cache */
/* replace159_0 -> replace149_0_0 in the cache */

/* replace159_1 -> replace149_0_1 in the cache */
/* replace159 -> replace149_0 in the cache */

   /* search160_0_0 -> search120_0_0 in the cache */
/* search160_0 -> search120_0 in the cache */
static const nir_search_expression search160 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search120_0.value },
   NULL,
};

   /* replace160_0_0_0 -> search120_0_0 in the cache */

/* replace160_0_0_1 -> replace132_0_0_1 in the cache */
/* replace160_0_0 -> replace132_0_0 in the cache */

/* replace160_0_1 -> replace132_0_0_1 in the cache */
/* replace160_0 -> replace132_0 in the cache */
static const nir_search_expression replace160 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &replace132_0.value },
   NULL,
};

   /* search161_0_0 -> search121_0_0 in the cache */
/* search161_0 -> search121_0 in the cache */
static const nir_search_expression search161 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search121_0.value },
   NULL,
};

   /* replace161_0_0_0 -> search121_0_0 in the cache */

/* replace161_0_0_1 -> replace133_0_0_1 in the cache */
/* replace161_0_0 -> replace133_0_0 in the cache */

/* replace161_0_1 -> replace133_0_0_1 in the cache */
/* replace161_0 -> replace133_0 in the cache */
static const nir_search_expression replace161 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &replace133_0.value },
   NULL,
};

   /* search162_0_0 -> search120_0_0 in the cache */
/* search162_0 -> search122_0 in the cache */
static const nir_search_expression search162 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search122_0.value },
   NULL,
};

   /* replace162_0_0_0 -> search120_0_0 in the cache */

/* replace162_0_0_1 -> replace132_0_0_1 in the cache */
/* replace162_0_0 -> replace132_0_0 in the cache */

/* replace162_0_1 -> replace132_0_0_1 in the cache */
/* replace162_0 -> replace132_0 in the cache */
/* replace162 -> replace160 in the cache */

   /* search163_0_0 -> search121_0_0 in the cache */
/* search163_0 -> search123_0 in the cache */
static const nir_search_expression search163 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search123_0.value },
   NULL,
};

   /* replace163_0_0_0 -> search121_0_0 in the cache */

/* replace163_0_0_1 -> replace133_0_0_1 in the cache */
/* replace163_0_0 -> replace133_0_0 in the cache */

/* replace163_0_1 -> replace133_0_0_1 in the cache */
/* replace163_0 -> replace133_0 in the cache */
/* replace163 -> replace161 in the cache */

   /* search164_0_0 -> search120_0_0 in the cache */
/* search164_0 -> search148_0 in the cache */
static const nir_search_expression search164 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search148_0.value },
   NULL,
};

   /* replace164_0_0 -> search120_0_0 in the cache */

static const nir_search_constant replace164_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0xc0e0000000000000L /* -32768.0 */ },
};
static const nir_search_expression replace164_0 = {
   { nir_search_value_expression, 32 },
   false, false,
   1, 1,
   nir_op_fmax,
   { &search120_0_0.value, &replace164_0_1.value },
   NULL,
};

static const nir_search_constant replace164_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x40dfffc000000000 /* 32767.0 */ },
};
static const nir_search_expression replace164 = {
   { nir_search_value_expression, 32 },
   false, false,
   0, 2,
   nir_op_fmin,
   { &replace164_0.value, &replace164_1.value },
   NULL,
};

   /* search165_0_0 -> search121_0_0 in the cache */
/* search165_0 -> search149_0 in the cache */
static const nir_search_expression search165 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search149_0.value },
   NULL,
};

   /* replace165_0_0_0 -> search121_0_0 in the cache */

static const nir_search_constant replace165_0_0_1 = {
   { nir_search_value_constant, 64 },
   nir_type_float, { 0xc0e0000000000000L /* -32768.0 */ },
};
static const nir_search_expression replace165_0_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   1, 1,
   nir_op_fmax,
   { &search121_0_0.value, &replace165_0_0_1.value },
   NULL,
};

static const nir_search_constant replace165_0_1 = {
   { nir_search_value_constant, 64 },
   nir_type_float, { 0x40dfffc000000000 /* 32767.0 */ },
};
static const nir_search_expression replace165_0 = {
   { nir_search_value_expression, 64 },
   false, false,
   0, 2,
   nir_op_fmin,
   { &replace165_0_0.value, &replace165_0_1.value },
   NULL,
};
static const nir_search_expression replace165 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 2,
   nir_op_f2f32,
   { &replace165_0.value },
   NULL,
};

   /* search166_0_0 -> search120_0_0 in the cache */
/* search166_0 -> search150_0 in the cache */
static const nir_search_expression search166 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search150_0.value },
   NULL,
};

   /* replace166_0_0 -> search120_0_0 in the cache */

/* replace166_0_1 -> replace164_0_1 in the cache */
/* replace166_0 -> replace164_0 in the cache */

/* replace166_1 -> replace164_1 in the cache */
/* replace166 -> replace164 in the cache */

   /* search167_0_0 -> search121_0_0 in the cache */
/* search167_0 -> search151_0 in the cache */
static const nir_search_expression search167 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_i2f32,
   { &search151_0.value },
   NULL,
};

   /* replace167_0_0_0 -> search121_0_0 in the cache */

/* replace167_0_0_1 -> replace165_0_0_1 in the cache */
/* replace167_0_0 -> replace165_0_0 in the cache */

/* replace167_0_1 -> replace165_0_1 in the cache */
/* replace167_0 -> replace165_0 in the cache */
/* replace167 -> replace165 in the cache */

   /* search168_0_0 -> search120_0_0 in the cache */
/* search168_0 -> search120_0 in the cache */
static const nir_search_expression search168 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search120_0.value },
   NULL,
};

   /* replace168_0_0_0 -> search120_0_0 in the cache */

/* replace168_0_0_1 -> replace132_0_0_1 in the cache */
/* replace168_0_0 -> replace132_0_0 in the cache */

/* replace168_0_1 -> replace132_0_0_1 in the cache */
/* replace168_0 -> replace132_0 in the cache */
static const nir_search_expression replace168 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &replace132_0.value },
   NULL,
};

   /* search169_0_0 -> search121_0_0 in the cache */
/* search169_0 -> search121_0 in the cache */
static const nir_search_expression search169 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search121_0.value },
   NULL,
};

   /* replace169_0_0_0 -> search121_0_0 in the cache */

/* replace169_0_0_1 -> replace133_0_0_1 in the cache */
/* replace169_0_0 -> replace133_0_0 in the cache */

/* replace169_0_1 -> replace133_0_0_1 in the cache */
/* replace169_0 -> replace133_0 in the cache */
static const nir_search_expression replace169 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &replace133_0.value },
   NULL,
};

   /* search170_0_0 -> search120_0_0 in the cache */
/* search170_0 -> search122_0 in the cache */
static const nir_search_expression search170 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search122_0.value },
   NULL,
};

   /* replace170_0_0_0 -> search120_0_0 in the cache */

/* replace170_0_0_1 -> replace132_0_0_1 in the cache */
/* replace170_0_0 -> replace132_0_0 in the cache */

/* replace170_0_1 -> replace132_0_0_1 in the cache */
/* replace170_0 -> replace132_0 in the cache */
/* replace170 -> replace168 in the cache */

   /* search171_0_0 -> search121_0_0 in the cache */
/* search171_0 -> search123_0 in the cache */
static const nir_search_expression search171 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search123_0.value },
   NULL,
};

   /* replace171_0_0_0 -> search121_0_0 in the cache */

/* replace171_0_0_1 -> replace133_0_0_1 in the cache */
/* replace171_0_0 -> replace133_0_0 in the cache */

/* replace171_0_1 -> replace133_0_0_1 in the cache */
/* replace171_0 -> replace133_0 in the cache */
/* replace171 -> replace169 in the cache */

   /* search172_0_0 -> search120_0_0 in the cache */
/* search172_0 -> search148_0 in the cache */
static const nir_search_expression search172 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search148_0.value },
   NULL,
};

   /* replace172_0_0_0 -> search120_0_0 in the cache */

/* replace172_0_0_1 -> replace164_0_1 in the cache */
/* replace172_0_0 -> replace164_0 in the cache */

/* replace172_0_1 -> replace164_1 in the cache */
/* replace172_0 -> replace164 in the cache */
static const nir_search_expression replace172 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 2,
   nir_op_f2f64,
   { &replace164.value },
   NULL,
};

   /* search173_0_0 -> search121_0_0 in the cache */
/* search173_0 -> search149_0 in the cache */
static const nir_search_expression search173 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search149_0.value },
   NULL,
};

   /* replace173_0_0 -> search121_0_0 in the cache */

/* replace173_0_1 -> replace165_0_0_1 in the cache */
/* replace173_0 -> replace165_0_0 in the cache */

/* replace173_1 -> replace165_0_1 in the cache */
/* replace173 -> replace165_0 in the cache */

   /* search174_0_0 -> search120_0_0 in the cache */
/* search174_0 -> search150_0 in the cache */
static const nir_search_expression search174 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search150_0.value },
   NULL,
};

   /* replace174_0_0_0 -> search120_0_0 in the cache */

/* replace174_0_0_1 -> replace164_0_1 in the cache */
/* replace174_0_0 -> replace164_0 in the cache */

/* replace174_0_1 -> replace164_1 in the cache */
/* replace174_0 -> replace164 in the cache */
/* replace174 -> replace172 in the cache */

   /* search175_0_0 -> search121_0_0 in the cache */
/* search175_0 -> search151_0 in the cache */
static const nir_search_expression search175 = {
   { nir_search_value_expression, 64 },
   false, false,
   -1, 0,
   nir_op_i2f64,
   { &search151_0.value },
   NULL,
};

   /* replace175_0_0 -> search121_0_0 in the cache */

/* replace175_0_1 -> replace165_0_0_1 in the cache */
/* replace175_0 -> replace165_0_0 in the cache */

/* replace175_1 -> replace165_0_1 in the cache */
/* replace175 -> replace165_0 in the cache */

   /* search176_0_0 -> search120_0_0 in the cache */
/* search176_0 -> search120_0 in the cache */
static const nir_search_expression search176 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_f2f32,
   { &search120_0.value },
   NULL,
};

   /* replace176_0 -> search120_0_0 in the cache */
static const nir_search_expression replace176 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_unpack_half_2x16_split_x,
   { &search120_0_0.value },
   NULL,
};

   /* search177_0_0 -> search120_0_0 in the cache */
static const nir_search_expression search177_0 = {
   { nir_search_value_expression, 16 },
   false, false,
   -1, 0,
   nir_op_f2f16_rtz,
   { &search120_0_0.value },
   NULL,
};
static const nir_search_expression search177 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_u2u32,
   { &search177_0.value },
   NULL,
};

   /* replace177_0 -> search120_0_0 in the cache */

static const nir_search_constant replace177_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x0 /* 0 */ },
};
static const nir_search_expression replace177 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_pack_half_2x16_split,
   { &search120_0_0.value, &replace177_1.value },
   NULL,
};


static const struct transform dxil_nir_lower_16bit_conv_state7_xforms[] = {
  { &search120, &replace120.value, 0 },
  { &search121, &replace121.value, 0 },
  { &search126, &replace126.value, 0 },
  { &search127, &replace121_0.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state8_xforms[] = {
  { &search122, &replace122.value, 0 },
  { &search123, &replace121.value, 0 },
  { &search128, &replace126.value, 0 },
  { &search129, &replace129.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state9_xforms[] = {
  { &search124, &replace124.value, 0 },
  { &search130, &replace130.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state10_xforms[] = {
  { &search125, &replace125.value, 0 },
  { &search131, &replace131.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state11_xforms[] = {
  { &search177, &replace177.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state12_xforms[] = {
  { &search132, &replace132.value, 0 },
  { &search133, &replace133.value, 0 },
  { &search138, &replace138.value, 0 },
  { &search139, &replace139.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state13_xforms[] = {
  { &search134, &replace132_0.value, 0 },
  { &search135, &replace133.value, 0 },
  { &search140, &replace138.value, 0 },
  { &search141, &replace133_0.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state14_xforms[] = {
  { &search136, &replace136.value, 0 },
  { &search142, &replace142.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state15_xforms[] = {
  { &search137, &replace137.value, 0 },
  { &search143, &replace143.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state16_xforms[] = {
  { &search144, &replace144.value, 0 },
  { &search145, &replace145.value, 0 },
  { &search152, &replace152.value, 0 },
  { &search153, &replace153.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state17_xforms[] = {
  { &search146, &replace144.value, 0 },
  { &search147, &replace145.value, 0 },
  { &search154, &replace152.value, 0 },
  { &search155, &replace153.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state18_xforms[] = {
  { &search148, &replace148.value, 0 },
  { &search149, &replace149.value, 0 },
  { &search156, &replace156.value, 0 },
  { &search157, &replace149_0.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state19_xforms[] = {
  { &search150, &replace148.value, 0 },
  { &search151, &replace149.value, 0 },
  { &search158, &replace156.value, 0 },
  { &search159, &replace149_0.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state20_xforms[] = {
  { &search160, &replace160.value, 0 },
  { &search161, &replace161.value, 0 },
  { &search168, &replace168.value, 0 },
  { &search169, &replace169.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state21_xforms[] = {
  { &search162, &replace160.value, 0 },
  { &search163, &replace161.value, 0 },
  { &search170, &replace168.value, 0 },
  { &search171, &replace169.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state22_xforms[] = {
  { &search164, &replace164.value, 0 },
  { &search165, &replace165.value, 0 },
  { &search172, &replace172.value, 0 },
  { &search173, &replace165_0.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state23_xforms[] = {
  { &search166, &replace164.value, 0 },
  { &search167, &replace165.value, 0 },
  { &search174, &replace172.value, 0 },
  { &search175, &replace165_0.value, 0 },
};
static const struct transform dxil_nir_lower_16bit_conv_state24_xforms[] = {
  { &search176, &replace176.value, 0 },
};

static const struct per_op_table dxil_nir_lower_16bit_conv_table[nir_num_search_ops] = {
   [nir_search_op_u2u] = {
      .filter = (uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         5,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (uint16_t []) {
      
         2,
         7,
         8,
         9,
         10,
         11,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         3,
         12,
         13,
         14,
         15,
      },
   },
   [nir_search_op_f2u] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         4,
      },
   },
   [nir_search_op_f2i] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         5,
      },
   },
   [nir_search_op_u2f] = {
      .filter = (uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         0,
         16,
         17,
         18,
         19,
      },
   },
   [nir_search_op_i2f] = {
      .filter = (uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         0,
         20,
         21,
         22,
         23,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (uint16_t []) {
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         24,
      },
   },
   [nir_op_f2f16_rtz] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         6,
      },
   },
};

const struct transform *dxil_nir_lower_16bit_conv_transforms[] = {
   NULL,
   NULL,
   NULL,
   NULL,
   NULL,
   NULL,
   NULL,
   dxil_nir_lower_16bit_conv_state7_xforms,
   dxil_nir_lower_16bit_conv_state8_xforms,
   dxil_nir_lower_16bit_conv_state9_xforms,
   dxil_nir_lower_16bit_conv_state10_xforms,
   dxil_nir_lower_16bit_conv_state11_xforms,
   dxil_nir_lower_16bit_conv_state12_xforms,
   dxil_nir_lower_16bit_conv_state13_xforms,
   dxil_nir_lower_16bit_conv_state14_xforms,
   dxil_nir_lower_16bit_conv_state15_xforms,
   dxil_nir_lower_16bit_conv_state16_xforms,
   dxil_nir_lower_16bit_conv_state17_xforms,
   dxil_nir_lower_16bit_conv_state18_xforms,
   dxil_nir_lower_16bit_conv_state19_xforms,
   dxil_nir_lower_16bit_conv_state20_xforms,
   dxil_nir_lower_16bit_conv_state21_xforms,
   dxil_nir_lower_16bit_conv_state22_xforms,
   dxil_nir_lower_16bit_conv_state23_xforms,
   dxil_nir_lower_16bit_conv_state24_xforms,
};

const uint16_t dxil_nir_lower_16bit_conv_transform_counts[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state7_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state8_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state9_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state10_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state11_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state12_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state13_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state14_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state15_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state16_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state17_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state18_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state19_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state20_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state21_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state22_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state23_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_16bit_conv_state24_xforms),
};

bool
dxil_nir_lower_16bit_conv(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[1];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   condition_flags[0] = true;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        dxil_nir_lower_16bit_conv_transforms,
                                        dxil_nir_lower_16bit_conv_transform_counts,
                                        dxil_nir_lower_16bit_conv_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 4
 * transforms:
 *    ('b2b32', 'a') => ('b2i32', 'a')
 *    ('b2b1', 'a') => ('i2b1', 'a')
 *    ('i2b1', 'a') => ('ine', 'a', 0)
 *    ('f2b1', 'a') => ('fneu', 'a', 0)
 */


   static const nir_search_variable search178_0 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
};
static const nir_search_expression search178 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_b2b32,
   { &search178_0.value },
   NULL,
};

   /* replace178_0 -> search178_0 in the cache */
static const nir_search_expression replace178 = {
   { nir_search_value_expression, 32 },
   false, false,
   -1, 0,
   nir_op_b2i32,
   { &search178_0.value },
   NULL,
};

   /* search179_0 -> search178_0 in the cache */
static const nir_search_expression search179 = {
   { nir_search_value_expression, 1 },
   false, false,
   -1, 0,
   nir_op_b2b1,
   { &search178_0.value },
   NULL,
};

   /* replace179_0 -> search178_0 in the cache */
static const nir_search_expression replace179 = {
   { nir_search_value_expression, 1 },
   false, false,
   -1, 0,
   nir_op_i2b1,
   { &search178_0.value },
   NULL,
};

   /* search180_0 -> search178_0 in the cache */
/* search180 -> replace179 in the cache */

   /* replace180_0 -> search178_0 in the cache */

static const nir_search_constant replace180_1 = {
   { nir_search_value_constant, -1 },
   nir_type_int, { 0x0 /* 0 */ },
};
static const nir_search_expression replace180 = {
   { nir_search_value_expression, 1 },
   false, false,
   0, 1,
   nir_op_ine,
   { &search178_0.value, &replace180_1.value },
   NULL,
};

   /* search181_0 -> search178_0 in the cache */
static const nir_search_expression search181 = {
   { nir_search_value_expression, 1 },
   false, false,
   -1, 0,
   nir_op_f2b1,
   { &search178_0.value },
   NULL,
};

   /* replace181_0 -> search178_0 in the cache */

/* replace181_1 -> replace180_1 in the cache */
static const nir_search_expression replace181 = {
   { nir_search_value_expression, 1 },
   false, false,
   0, 1,
   nir_op_fneu,
   { &search178_0.value, &replace180_1.value },
   NULL,
};


static const struct transform dxil_nir_lower_x2b_state2_xforms[] = {
  { &search178, &replace178.value, 0 },
};
static const struct transform dxil_nir_lower_x2b_state3_xforms[] = {
  { &search179, &replace179.value, 0 },
};
static const struct transform dxil_nir_lower_x2b_state4_xforms[] = {
  { &replace179, &replace180.value, 0 },
};
static const struct transform dxil_nir_lower_x2b_state5_xforms[] = {
  { &search181, &replace181.value, 0 },
};

static const struct per_op_table dxil_nir_lower_x2b_table[nir_num_search_ops] = {
   [nir_op_b2b32] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         2,
      },
   },
   [nir_op_b2b1] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         3,
      },
   },
   [nir_search_op_i2b] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         4,
      },
   },
   [nir_search_op_f2b] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         5,
      },
   },
};

const struct transform *dxil_nir_lower_x2b_transforms[] = {
   NULL,
   NULL,
   dxil_nir_lower_x2b_state2_xforms,
   dxil_nir_lower_x2b_state3_xforms,
   dxil_nir_lower_x2b_state4_xforms,
   dxil_nir_lower_x2b_state5_xforms,
};

const uint16_t dxil_nir_lower_x2b_transform_counts[] = {
   0,
   0,
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_x2b_state2_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_x2b_state3_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_x2b_state4_xforms),
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_x2b_state5_xforms),
};

bool
dxil_nir_lower_x2b(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[1];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   condition_flags[0] = true;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        dxil_nir_lower_x2b_transforms,
                                        dxil_nir_lower_x2b_transform_counts,
                                        dxil_nir_lower_x2b_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 1
 * transforms:
 *    ('inot', 'a') => ('ixor', 'a', -1)
 */


   static const nir_search_variable search182_0 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
};
static const nir_search_expression search182 = {
   { nir_search_value_expression, -1 },
   false, false,
   -1, 0,
   nir_op_inot,
   { &search182_0.value },
   NULL,
};

   /* replace182_0 -> search182_0 in the cache */

static const nir_search_constant replace182_1 = {
   { nir_search_value_constant, -1 },
   nir_type_int, { -0x1 /* -1 */ },
};
static const nir_search_expression replace182 = {
   { nir_search_value_expression, -1 },
   false, false,
   0, 1,
   nir_op_ixor,
   { &search182_0.value, &replace182_1.value },
   NULL,
};


static const struct transform dxil_nir_lower_inot_state2_xforms[] = {
  { &search182, &replace182.value, 0 },
};

static const struct per_op_table dxil_nir_lower_inot_table[nir_num_search_ops] = {
   [nir_op_inot] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         2,
      },
   },
};

const struct transform *dxil_nir_lower_inot_transforms[] = {
   NULL,
   NULL,
   dxil_nir_lower_inot_state2_xforms,
};

const uint16_t dxil_nir_lower_inot_transform_counts[] = {
   0,
   0,
   (uint16_t)ARRAY_SIZE(dxil_nir_lower_inot_state2_xforms),
};

bool
dxil_nir_lower_inot(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[1];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   condition_flags[0] = true;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        dxil_nir_lower_inot_transforms,
                                        dxil_nir_lower_inot_transform_counts,
                                        dxil_nir_lower_inot_table);
      }
   }

   return progress;
}

